import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, Radio, InputNumber, Card, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { ChargePropertyPackage } from '../../services/charge'
import './index.scss'

const ChargeHouse: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '物业缴费周期',
      dataIndex: 'pay_months',
      search: false,
    },
    {
      title: '物业赠送',
      dataIndex: 'give_months',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'enable',
      valueType: 'switch',
      search: false,
    },
    {
      title: '赠送文本',
      dataIndex: 'give_content',
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a style={{marginRight: 20 }} onClick={() => {
          setEditRow(row)
          Modal.confirm({
            title: '更改状态',
            content: '你确定修改状态吗？',
            onOk: async () => {
              await ChargePropertyPackage({ method: 'put', ...row, enable: !row.enable })
              message.success('操作成功')
              actionRef.current.reload()
            }
          })
        }}>{row.enable ? '禁用' : '启用'}</a>,
        <a style={{marginRight: 20 }} onClick={() => {
          setEditRow(row)
          form.setFieldsValue(row)
          setState(prevState => ({
            ...prevState,
            visible: true,
            packageType: row.package_type
          }))
        }}>编辑</a>,
        <a onClick={() => {
          Modal.confirm({
            title: '删除记录',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await ChargePropertyPackage({ method: 'delete', id: row.id })
              actionRef.current.reload()
            }
          })
        }}>删除</a>
      ]
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    packageType: 1
  })
  const [editRow, setEditRow]: any = React.useState({})

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await ChargePropertyPackage({ method: editRow.id ? 'put' : 'post', ...values, id: editRow.id })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(pre => ({ ...pre, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={ChargePropertyPackage}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, visible: true }))
              setEditRow({})
            }}
          >添加物业缴费优惠</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={editRow.id ? '编辑物业预缴套餐' : '添加物业预缴套餐'}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='物业缴费周期' name="pay_months" rules={[{ required: true }]}>
            <InputNumber placeholder='请输入' />
          </Form.Item>
          <Form.Item label='定义类型' name="package_type" rules={[{ required: true }]}>
            <Radio.Group onChange={(event) => {
              setState(prevState => ({
                ...prevState,
                packageType: event.target.value
              }))
            }}>
              <Radio value={1}>月份</Radio>
              <Radio value={2}>文本</Radio>
            </Radio.Group>
          </Form.Item>
          {
            state.packageType === 1 ? <Form.Item label='赠送物业时间' name="give_months" rules={[{ required: true }]}>
              <InputNumber placeholder='请输入' />
            </Form.Item> : <Form.Item label='自定义内容' name="give_content" rules={[{ required: true }]}>
              <Input placeholder='请输入' />
            </Form.Item>
          }
          <Form.Item label='状态' name="enable" rules={[{ required: true }]}>
            <Radio.Group>
              <Radio value={true}>启用</Radio>
              <Radio value={false}>关闭</Radio>
            </Radio.Group>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeHouse)
