import React from 'react'
import {Button, Divider, Form, Row, Col, Card, Table, Select, Modal, Input, InputNumber, message} from "antd"
import { CHARGE_TYPES } from '../../CONSTANT'
import { GetChargeObjBillList, ChargePay } from '../../services/entity'
import './index.scss'

const BillHandle: React.FC = (props: any) => {

  const columns = [
    {
      title: '账单开始时间',
      dataIndex: 'start'
    },
    {
      title: '账单结束时间',
      dataIndex: 'end'
    },
    {
      title: '金额',
      dataIndex: 'amount'
    },
  ]

  const [payForm]: any = Form.useForm()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    successVisible: false,
    chargeType: '',
    billData: {}
  }))

  const onPay = () => {
    payForm.validateFields().then(async values => {
      await ChargePay({
        bind_ids: [props.rowData.bind_id],
        ...values
      })
      message.success('缴费成功！')
      payForm.resetFields()
      setState(prevState => ({ ...prevState, successVisible: true }))
    })
  }

  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      chargeType: CHARGE_TYPES[props.rowData.charge_type].text
    }))
    GetChargeObjBillList({
      bind_id: props.rowData.bind_id,
      page: 1,
      pageSize: 9999
    }).then(res => {
      setState(prevState => ({
        ...prevState,
        billData: res
      }))
    })
  }, [])

  return (
    <Card>
      <div className={'page-line'}>
        { props.query.name }
        {/*<Button type='primary'>返回</Button>*/}
      </div>
      <Divider/>
      <Form>
        <Row>
          <Col span={12}>
            <Form.Item label={'费项名称'}>
              { props.rowData.charge_name }
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用说明'}>
              { props.rowData.desc }
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用类型'}>
              { state.chargeType }
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'应收款'}>
              <span className={'form-item__price'}>
                { state.billData?.should_pay_amount }
              </span>
            </Form.Item>
          </Col>
        </Row>
        <Row className={'mt-2'}>
          <Col span={24}>
            <Table
              columns={columns}
              dataSource={state.billData?.data}
              pagination={false}
            />
          </Col>
        </Row>
        <Row className={'mt-6 flex justify-end'}>
          <Form.Item style={{ width: 180 }} label='支付方式'>
            <Select
              placeholder='请选择'
              options={[
                { label: '现金', value: 1 },
                { label: '微信', value: 2 },
                { label: '支付宝', value: 3 },
                { label: 'pos', value: 4 },
                { label: '转账', value: 5 },
              ]}
              onChange={(value) => {
                payForm.setFieldsValue({ pay_type: value })
              }}
            />
          </Form.Item>
          <Button className={'ml-2'} type={'primary'} onClick={() => {
            if (!payForm.getFieldValue('pay_type')) return message.error('请选择支付方式')
            setState(prevState => ({ ...prevState, visible: true }))
            payForm.setFieldsValue({ should_pay_amount: state.billData?.should_pay_amount || 0 })
          }}>收费</Button>
        </Row>
      </Form>
      <Modal
        visible={state.visible}
        title={'收费确认'}
        onOk={onPay}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form labelCol={{ span: 5 }} form={payForm}>
          <Form.Item label='缴费对象'>
            { props.query.name }
          </Form.Item>
          <Form.Item label='应收金额' name="should_pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" disabled placeholder="请输入"/>
          </Form.Item>
          <Form.Item label='实收金额' name="pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" placeholder="请输入"/>
          </Form.Item>
          <Form.Item label='支付方式' name="pay_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' disabled options={[
              { label: '现金', value: 1 },
              { label: '微信', value: 2 },
              { label: '支付宝', value: 3 },
              { label: 'pos', value: 4 },
              { label: '转账', value: 5 },
            ]} />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea placeholder='多行输入' rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title={'缴费提示'}
        visible={state.successVisible}
        footer={false}
        onCancel={() => setState(prevState => ({
          ...prevState,
          successVisible: false,
          visible: false
        }))}
      >
        缴费成功！
        <div className={'mt-2'}>
          <Button className={'mr-4'}>返回</Button>
          <Button
            className={'mr-4'}
            type={'primary'}
            onClick={() => {
              window.document.body.innerHTML = window.document.body.innerHTML
              window.print()
              window.location.reload()
            }}>打印小票</Button>
          <Button className={'mr-4'} type={'primary'} onClick={() => {
            window.document.body.innerHTML = window.document.body.innerHTML
            window.print()
            window.location.reload()
          }}>打印收据</Button>
        </div>
      </Modal>
    </Card>
  )
}

export default BillHandle as any
