import React from 'react'
import {
  Button,
  Divider,
  Form,
  Row,
  Col,
  Card,
  InputNumber,
  Select,
  Modal,
  Input,
  DatePicker
} from "antd"
import './index.scss'
import { ChargePrePay, ChargePrePayInfo } from '../../services/charge'
import { SELECTOR_PAY_TYPES, CHARGE_TYPES } from '../../CONSTANT'
import { useHistory } from "react-router"
import querystring from "querystring"

const BillPreStore: React.FC = () => {

  const history = useHistory()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    successVisible: false,
    query: {},
    chargeType: null
  }))

  React.useEffect(() => {
    const query = querystring.parse(history.location.search.split('?')[1])
    setState(prevState => ({
      ...prevState,
      query,
      chargeType: CHARGE_TYPES[query.obj_type]?.text
    }))
  }, [])

  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(values => {
      ChargePrePay({
        ...values,
        should_pay_amount: 100,
        bind_id: +state.query.obj_id,
        months: values.months.valueOf()
      })
      Modal.confirm({
        title: '操作成功',
        content: '点击确认返回账单列表',
        onOk: () => {
          history.goBack()
        }
      })
    })
  }


  const getInfo = async (month) => {
    const data = await ChargePrePayInfo({
      bind_id: state.query.obj_id,
      months: new Date(month).getMonth() + 1
    })
    console.log(data)
  }

  return (
    <Card>
      <div className={'page-line'}>
        { state.query.name }
        <Button type='primary' onClick={history.goBack}>返回</Button>
      </div>
      <Divider/>
      <Form labelCol={{ span: 5 }} form={form}>
        <Row>
          <Col span={12}>
            <Form.Item label={'费项名称'}>
              { state.query.name + state.chargeType }
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="费用说明">
             未知.
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'费用类型'} name="charge_type">
              { state.chargeType }
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'应收款'} name="should_pay_amount">
              <span className={'form-item__price'}>0</span>
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={'缴费周期'} name="months" rules={[{ required: true }]}>
              <DatePicker.MonthPicker placeholder="请选择" onChange={getInfo} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='支付方式' name="pay_type" rules={[{ required: true }]}>
              <Select style={{ width: 180 }} placeholder={'请选择'} options={SELECTOR_PAY_TYPES} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
              <Input.TextArea placeholder={'多行输入'} rows={4} />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label='实际收款' name="pay_amount" rules={[{ required: true }]}>
              <InputNumber style={{ width: 180 }} placeholder={'请输入'} />
            </Form.Item>
          </Col>
        </Row>
        <Row className={'mt-6 flex justify-end'}>
          <Button className={'ml-2'} type={'primary'} onClick={onSubmit}>收费</Button>
        </Row>
      </Form>
      <Modal
        title='缴费提示'
        visible={state.successVisible}
        footer={false}
        onCancel={() => setState(prevState => ({
          ...prevState,
          successVisible: false,
          visible: false
        }))}
      >
        缴费成功！
        <div className={'mt-2'}>
          <Button className={'mr-4'}>返回</Button>
          <Button
            className={'mr-4'}
            type={'primary'}
            onClick={() => {
              window.document.body.innerHTML = window.document.body.innerHTML
              window.print()
              window.location.reload()
            }}>打印小票</Button>
          <Button className={'mr-4'} type={'primary'} onClick={() => {
            window.document.body.innerHTML = window.document.body.innerHTML
            window.print()
            window.location.reload()
          }}>打印收据</Button>
        </div>
      </Modal>
    </Card>
  )
}

export default BillPreStore
