import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Card, Modal, Form, Select, Input, InputNumber, message } from "antd"
import { useHistory } from "react-router"
import querystring from "querystring"
import { GetChargeObjUnPay, ChargePay } from "../../services/entity"

const columns: any = [
  {
    title: '费用类型',
    dataIndex: 'charge_type',
    valueEnum: {
      1: { text: '物业费' },
      2: { text: '水费' },
      3: { text: '电费' },
      4: { text: '气费' },
      5: { text: '车位管理费' },
      6: { text: '月租停车费' },
      99: { text: '其他' }
    },
  },
  {
    title: '费项名称',
    dataIndex: 'charge_name'
  },
  {
    title: '费用标识',
    dataIndex: 'charge_time_type',
    valueEnum: {
      1: {
        text: '周期性缴'
      },
      2: {
        text: '一次性'
      }
    }
  },
  {
    title: '账单数',
    dataIndex: 'bill_count'
  },
  {
    title: '欠费金额',
    dataIndex: 'unpay_amount'
  }
]

export const HouseArrears:React.FC = () => {
  const [form] = Form.useForm()
  const actionRef = React.useRef<ActionType>()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    query: {}
  }))
  const [selectedRow, setSelectedRow]: any = React.useState({
    values: [],
    keys: []
  })
  const [payAmount, setPayAmount] = React.useState(0)
  const history: any = useHistory()
  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      query: querystring.parse(history.location.search.split('?')[1])
    }))
  }, [])

  const onSubmit = () => {
    form.validateFields().then(async values => {
      await ChargePay({
        bind_ids: selectedRow.values.map(({ bind_id }) => bind_id),
        ...values
      })
      message.success('缴费成功！')
      // init
      form.resetFields()
      setState(prevState => ({ ...prevState, visible: false }))
      setSelectedRow({ values: [], keys: [] })
      setPayAmount(0)
      actionRef.current?.reload()
    })
  }

  return (
    <React.Fragment>
      <Card>
        <ProTable
          actionRef={actionRef}
          columns={columns}
          headerTitle={`房间 ${state?.query?.name}`}
          search={false}
          toolBarRender={() => [
            <Button type='primary' onClick={history.goBack}>返回</Button>
          ]}
          rowSelection={{
            columnWidth: 50,
            onChange: (selectedRowKeys: React.Key[], selectedRows: any) => {
              setSelectedRow({
                values: selectedRows,
                keys: selectedRowKeys
              })
              let amount = 0
              selectedRows.forEach(({ unpay_amount }) => {
                amount = amount + unpay_amount
              })
              setPayAmount(amount)
            },
            selectedRowKeys: selectedRow.keys
          }}
          params={state.query}
          request={GetChargeObjUnPay}
          pagination={false}
          bordered
        >

        </ProTable>
        <div className="mt-2.5">
          缴费金额：{ payAmount }
          <Button
            className={'ml-2'}
            type='primary'
            disabled={!selectedRow.values.length}
            onClick={() => {
              setState(prevState => ({
                ...prevState,
                visible: true
              }))
              form.setFieldsValue({
                should_pay_amount: payAmount
              })
            }}
          >缴费</Button>
        </div>
      </Card>
      <Modal
        width={420}
        visible={state.visible}
        title='收费确认'
        onOk={onSubmit}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form labelCol={{ span: 5 }} form={form}>
          <Form.Item label='房屋'>
            { state.query.name }
          </Form.Item>
          <Form.Item label='应收金额' name="should_pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" disabled placeholder="请输入"/>
          </Form.Item>
          <Form.Item label='实收金额' name="pay_amount" rules={[{ required: true }]}>
            <InputNumber className="w-4/5" placeholder="请输入"/>
          </Form.Item>
          {/*<Form.Item label='收费方式'>*/}
          {/*  <Select placeholder='请选择' options={[]} />*/}
          {/*</Form.Item>*/}
          <Form.Item label='支付方式' name="pay_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '现金', value: 1 },
              { label: '微信', value: 2 },
              { label: '支付宝', value: 3 },
              { label: 'pos', value: 4 },
              { label: '转账', value: 5 },
            ]} />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea placeholder='多行输入' rows={4} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default HouseArrears
