import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, Card, DatePicker } from 'antd'
import { withRouter } from 'react-router-dom'
import { GetChargeObjHouse } from '../../services/entity'
import './index.scss'

const ChargeHouse: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'house_id',
      search: false
    },
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '楼层',
      dataIndex: 'layer',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'house_type',
      search: false,
      valueEnum: {
        1: {
          text: '公寓'
        },
        2: {
          text: '住房'
        }
      },
    },
    {
      title: '建筑面积',
      dataIndex: 'house_area',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'house_used_area',
      search: false,
    },
    {
      title: '房屋状态',
      dataIndex: 'house_status',
      search: false,
      valueEnum: {
        1: {
          text: '已入驻'
        },
        2: {
          text: '未入驻'
        }
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        const queryParams = `?obj_type=1&obj_id=${row.house_id}&name=${row.house_name}`
        return [
          <div className='controller-group'>
            <a style={{marginRight: 20 }} onClick={() => {
              props.history.push('/admin/charge/house-arrears' + queryParams)
            }}>欠费缴费</a>
            <a style={{marginRight: 20 }} onClick={() => {
              props.history.push('/admin/charge/house-bill' + queryParams)
            }}>查明费用</a>
            <a onClick={() => {
              props.history.push('/admin/charge/prestore' + queryParams)
            }}>预存物业费</a>
          </div>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false
  })

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={GetChargeObjHouse}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
            }}
          >批量催缴单</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='批量创建房屋收费'
        visible={state.visible}
        width={680}
        onOk={() => setState(pre => ({ ...pre, visible: false }))}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
        >
          <Form.Item label='房屋类型'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='收费范围'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='楼栋'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='单元'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='房屋'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='楼层'>
            <Input placeholder='请输入'/>
          </Form.Item>
          <Form.Item label='费用类型'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='收费项目'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='房屋状态'>
            <Select placeholder='请选择'>
              <Select.Option value='1' children={[]}/>
            </Select>
          </Form.Item>
          <Form.Item label='计费开始时间'>
            <DatePicker />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeHouse)