import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import type { ProFormInstance } from '@ant-design/pro-form'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, DatePicker, Upload, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { ChargePower, GetHouseList, ChargePowerBatch, GetChargePowerTemplate } from "../../services/charge"
import moment from 'moment'

import './index.scss'

const GardenList: React.FC = (props: any) => {

  const formRef: any = React.useRef<ProFormInstance>()
  const actionRef: any = React.useRef<ActionType>()
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '房号',
      dataIndex: 'house_name',
      search: false
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      initialValue: '2',
      valueEnum: {
        2: {
          value: 2,
          text: '水费'
        },
        3: {
          value: 3,
          text: '电费'
        },
        4: {
          value: 4,
          text: '气费'
        }
      }
    },
    {
      title: '上期度数',
      dataIndex: 'last_amount',
      search: false,
    },
    {
      title: '本期度数',
      dataIndex: 'current_amount',
      search: false,
    },
    {
      title: '读表时间',
      dataIndex: 'read_at',
      valueType: 'dateTime',
      search: false,
    },
    {
      title: '开始时间',
      dataIndex: 'start',
      valueType: 'dateRange',
      render: (_, row: any) => <div>{ moment(row.start).format('YYYY-MM-DD HH:MM:ss') }</div>,
      search: {
        transform: (value: any) => ({ start: value[0], end: value[1] }),
      },
    },
    {
      title: '结束时间',
      dataIndex: 'end',
      valueType: 'dateTime',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  align: 'center',
	  width: 210,
      render: (_, row, index, action) => [
        <a type='link' onClick={() => {
          Modal.confirm({
            title: '确认删除这条记录吗?',
            content: '你确定删除这条记录吗？',
            onOk: async () => {
              await ChargePower({ method: 'delete', id: row.id })
              message.success('操作成功')
              actionRef.current.reload()
            },
            onCancel() {}
          });
        }}>删除</a>
      ]
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    editId: null
  })

  // 手动上传文件暂存
  let uploadFile: any = null

  const [houseState, setHouseState]: any = React.useState({
    data: []
  })

  const [form]: any = Form.useForm()

  const onSubmit = () => {
    form.validateFields().then(async values => {
      // 转换时间戳
      ['start', 'end'].forEach(key => {
        values[key] = values[key].valueOf()
      });
      ['current_amount', 'last_amount'].forEach(key => {
        values[key] = +parseFloat(values[key]).toFixed(2)
      })
      const charge_type = +formRef.current.getFieldsValue().charge_type
      await ChargePower({ method: 'post', charge_type, ...values })
      message.success('操作成功')
      actionRef.current.reloadAndRest()
      form.resetFields()
      // close modal
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  const getTemplate = async () => {
    const { data } = await GetChargePowerTemplate()
    window.open(data.url)
  }

  // @ts-ignore
  // eslint-disable-next-line react-hooks/exhaustive-deps
  React.useEffect(async () => {
    const data = await GetHouseList({
      page: 1,
      pageSize: 9999
    })
    setHouseState(data)
  }, [])

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={ChargePower}
        formRef={formRef}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
              form.setFieldsValue({ charge_type: formRef.current.getFieldsValue().charge_type })
            }}
          >
            <PlusOutlined /> 抄表
          </Button>,
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, exportVisible: true }))
            }}
          >抄表录入</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? '编辑抄表' : '添加抄表'}
        visible={state.visible}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          name="meter-form"
          form={form}
        >
          <Form.Item label='房屋' name="house_id" rules={[{ required: true }]}>
            <Select placeholder='请选择'>
              {
                houseState.data.map(item =>
                  <Select.Option value={item.house_id}>
                    { item.house_name }
                  </Select.Option>
                )
              }
            </Select>
          </Form.Item>
          <Form.Item label='上期度数' name="last_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入'/>
          </Form.Item>
          <Form.Item label='本期度数' name="current_amount" rules={[{ required: true }]}>
            <Input placeholder='单行输入'/>
          </Form.Item>
          <Form.Item label='开始时间' name="start" rules={[{ required: true }]}>
            <DatePicker className="w-4/5" placeholder='选择时间' format="YYYY-MM-DD" />
          </Form.Item>
          <Form.Item label='结束时间' name="end" rules={[{ required: true }]}>
            <DatePicker className="w-4/5" placeholder='选择时间' format="YYYY-MM-DD" />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea rows={4} placeholder='多行输入'/>
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='抄表导入'
        visible={state.exportVisible}
        onOk={async () => {
          if (!uploadFile) message.error('请先选择文件！')
          const files = new FormData()
          files.append('file', uploadFile)
          await ChargePowerBatch({
            charge_type: +formRef.current.getFieldsValue().charge_type,
            file: files
          })
          message.success('上传成功')
          actionRef.current.reloadAndRest()
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        destroyOnClose={true}
        onCancel={() => {
          setState(prevState => ({
            ...prevState,
            exportVisible: false
          }))
          uploadFile = null
        }}
        okText="导入"
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 16 }}
        >
          <Form.Item label='选择文件'>
            <Upload
              beforeUpload={file => {
                uploadFile = file
                return false
              }}
              maxCount={1}
            >
              <Button>选择文件</Button>
            </Upload>
          </Form.Item>
          <Form.Item label='下载模板'>
            请先下载 <span className='link-primary' onClick={getTemplate}>导入模板</span> 准备数据后，上传导入
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(GardenList)