import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Card, Modal, Form, DatePicker, message } from "antd"
import { useHistory } from "react-router"
import { GetChargeObjBill, ChangeChargeTime } from "../../services/entity"
import { CreateChargeBill } from "../../services/charge"
import { CHARGE_TYPES } from '../../CONSTANT'
import BillHandle from './bill-handle'
import querystring from "querystring"


const columns: any = [
  {
    title: 'ID',
    dataIndex: 'bind_id'
  },
  {
    title: '费用类型',
    dataIndex: 'charge_type',
    valueEnum: CHARGE_TYPES
  },
  {
    title: '费项名称',
    dataIndex: 'charge_name'
  },
  {
    title: '单价',
    dataIndex: 'charge_time_type'
  },
  {
    title: '建账时间',
    dataIndex: 'created_at'
  },
  {
    title: '说明',
    dataIndex: 'desc'
  }
]

export const ParkingPositionBill:React.FC = () => {
  const actionRef = React.useRef<ActionType>()
  const history = useHistory()
  const [state, setState]: any = React.useState(() => ({
    visible: false,
    billVisible: false,
    payVisible: false,
    query: {}
  }))

  const [editId, setEditId] = React.useState(null)
  const [rowData, setRowData] = React.useState({})
  const [form] = Form.useForm()
  const [billForm] = Form.useForm()

  React.useEffect(() => {
    setState(prevState => ({
      ...prevState,
      query: querystring.parse(history.location.search.split('?')[1])
    }))
  }, [])

  const columns2 = [
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        const buttons = [
          <a style={{marginRight: 20 }} onClick={() => {
            setRowData(row)
            setState(prevState => ({
              ...prevState,
              payVisible: true
            }))
          }}>缴费</a>,
          // <a size={'small'} onClick={() => {}}>取消</a>,
          <a style={{marginRight: 20 }} onClick={() => {
            setState(prevState => ({
              ...prevState,
              visible: true
            }))
            setEditId(row.bind_id)
          }}>变更</a>
        ]
        if (row.charge_time_type === 1 || [2, 3, 4].includes(row.charge_type)) {
          buttons.push(<a onClick={() => {
            setEditId(row.bind_id)
            billForm.resetFields()
            setState(prevState => ({
              ...prevState,
              billVisible: true
            }))
          }}>生成账单</a>)
        }
        return buttons
      }
    }
  ]

  const onSubmit = () => {
    form.validateFields().then(async values => {
      ['start', 'end'].forEach(key => {
        values[key] = values[key].valueOf()
      })
      await ChangeChargeTime({ bind_id: editId, ...values })
      message.success('变更成功！')
      actionRef.current?.reload()
      form.resetFields()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }
  const onCreateBill = () => {
    billForm.validateFields().then(async values => {
      ['end'].forEach(key => { values[key] = values[key].valueOf() })
      await CreateChargeBill({ bind_id: editId, ...values })
      message.success('操作成功！')
      setState(prevState => ({ ...prevState, billVisible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card>
        <ProTable
          actionRef={actionRef}
          columns={[...columns, ...columns2]}
          headerTitle={`${state.query.name}`}
          search={false}
          toolBarRender={() => [
            <Button type='primary' onClick={history.goBack}>返回</Button>
          ]}
          params={state.query}
          request={GetChargeObjBill}
          bordered
        >
        </ProTable>
      </Card>
      <Modal
        width={420}
        visible={state.billVisible}
        title="生成账单"
        onOk={onCreateBill}
        onCancel={() => setState(prevState => ({
          ...prevState,
          billVisible: false
        }))}
      >
        <Form form={billForm} labelCol={{ span: 7 }}>
          <Form.Item label="结束时间" name="end" rules={[{ required: true }]}>
            <DatePicker.MonthPicker placeholder='选择时间' />
          </Form.Item>
          <Form.Item label="tips">精确到月</Form.Item>
        </Form>
      </Modal>
      <Modal
        width={420}
        visible={state.visible}
        title="日期变更"
        onOk={onSubmit}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
      >
        <Form form={form} labelCol={{ span: 7 }}>
          <Form.Item label="计费开始时间" name="start" rules={[{ required: true }]}>
            <DatePicker placeholder='选择时间' />
          </Form.Item>
          <Form.Item label="计费结束时间" name="end" rules={[{ required: true }]}>
            <DatePicker placeholder='选择时间' />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title="缴费"
        width={1200}
        visible={state.payVisible}
        onCancel={() => setState(prevState => ({
          ...prevState,
          payVisible: false
        }))}
        footer={false}
        destroyOnClose={true}
      >
        <BillHandle
          query={state.query}
          rowData={rowData}
          success={() => {
            setState(prevState => ({
              ...prevState,
              payVisible: false
            }))
          }}
        />
      </Modal>
    </React.Fragment>
  )
}

export default ParkingPositionBill
