import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Select, Input, Card } from 'antd'
import { withRouter } from 'react-router-dom'
import { GetChargeObjParkingPosition } from '../../services/entity'
import { useParking } from "../Parking/hooks"
import './index.scss'

const ChargeHouse: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '区域名称',
      dataIndex: 'park_number',
      search: false,
    },
    {
      title: '停车场',
      dataIndex: 'park_name',
      hideInTable: true,
      valueType: 'select',
      search: true,
      renderFormItem: (_, { type, defaultRender, formItemProps, fieldProps, ...rest }, form) => {
        if (type === 'form') {
          return null;
        }
        const status = form.getFieldValue('state');
        if (status !== 'open') {
          return (
            // value 和 onchange 会通过 form 自动注入。
            <Select placeholder="请选择" options={parking} />
          );
        }
        return defaultRender(_);
      }
    },
    {
      title: '车位编号',
      dataIndex: 'space_number',
      search: true,
    },
    {
      title: '车位类型',
      dataIndex: 'space_type',
      search: true,
      valueEnum: {
        1: { text: '普通车位' },
        2: { text: '子母车位' },
        3: { text: '豪华车位' },
      }
    },
    {
      title: '面积',
      dataIndex: 'space_area',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  align: 'center',
	  width: 210,
      render: (_, row, index, action) => {
        const queryParams = `?obj_type=2&obj_id=${row.space_id}&name=${row.park_name}-${row.space_number}`
        return (
          <div className='controller-group'>
            {/*<Button onClick={() => {*/}
            {/*  props.history.push('/admin/charge/house-arrears' + queryParams)*/}
            {/*}}>欠费缴费</Button>*/}
            <a style={{marginRight: 20 }} onClick={() => {
              props.history.push('/admin/charge/parking-position/bill' + queryParams)
            }}>查明费用</a>
            <a onClick={() => {
              props.history.push('/admin/charge/prestore' + queryParams)
            }}>预存物业费</a>
          </div>
        )
      }
    }
  ]
  // const [state, setState] = React.useState({
  //   visible: false,
  //   exportVisible: false
  // })
  const [parking, setParking] = useParking()
  React.useEffect(() => {
    // init
    setParking()
  }, [])

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入车牌号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={GetChargeObjParkingPosition}
        columns={columns}
      />
    </React.Fragment>
  )
}

export default withRouter(ChargeHouse)