import React from 'react'
import ProTable from "@ant-design/pro-table"
import { Button, Modal, Form } from "antd"
import { GetPayedBill } from "../../services/charge"
import { CHARGE_TYPES, SELECTOR_PAY_TYPES  } from "../../CONSTANT"

const PayedBill:React.FC = () => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'bill_id',
      search: false,
    },
    {
      title: '房间/车位',
      dataIndex: 'obj_name',
      search: true,
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      search: true,
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      valueEnum: CHARGE_TYPES,
      search: true,
    },
    {
      title: '实缴金额',
      dataIndex: 'amount',
      search: false
    },
    {
      title: '支付方式',
      dataIndex: 'pay_type',
      search: false,
      valueEnum: () => {
        const enums = {}
        SELECTOR_PAY_TYPES.forEach(item => {
          enums[item.value] = {text: item.label}
        })
        return enums
      }
    },
    {
      title: '支付时间',
      dataIndex: 'pay_time',
      search: false
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a
          onClick={() => {
            setState(prevState => ({ ...prevState, visible: true }))
            setRowData(row)
          }}
        >详情</a>,
      ]
    }
  ]
  const [state, setState] = React.useState({ visible: false })
  const [rowData, setRowData] = React.useState({})

  return (
    <React.Fragment>
      <ProTable
        columns={columns}
        request={GetPayedBill}
        bordered
      />
      <Modal
        title="详情"
        visible={state.visible}
        footer={false}
        onCancel={() => setState(prevState => ({ ...prevState, visible: false }))}
      >
        <Form>
          {
            columns.slice(0, columns.length - 1).map(item => (
              <Form.Item label={item.title}>
                { rowData[item.dataIndex] }
              </Form.Item>
            ))
          }
          <Form.Item label="费用描述">
            { rowData['charge_desc'] }
          </Form.Item>
          <Form.Item label="开始时间-结束时间">
            { rowData['start'] } - { rowData['end'] }
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default PayedBill
