import React from 'react'
import ProTable, {ActionType} from "@ant-design/pro-table"
import { Button, Form, message, Modal, Select } from "antd";
import { GetChargeOrderList, GetChargeOrderInfo, ChargeOrderConfirm } from "../../services/charge"
import { SELECTOR_PAY_TYPES } from "../../CONSTANT"

const columns: any = [
  {
    title: 'ID',
    dataIndex: 'id',
    search: false,
  },
  {
    title: '房间/车位/车牌',
    dataIndex: 'obj_name',
    search: false,
  },
  {
    title: '车牌',
    dataIndex: 'obj_name',
    search: true,
    hideInTable: true
  },
  {
    title: '房间号',
    dataIndex: 'obj_name',
    search: true,
    hideInTable: true
  },
  {
    title: '订单号',
    dataIndex: 'order_id',
    search: true,
  },
  {
    title: '付款人',
    dataIndex: 'id',
    search: false,
  },
  {
    title: '付款人电话',
    dataIndex: 'name',
    search: false
  },
  {
    title: '总费用',
    dataIndex: 'should_pay_amount',
    search: false,
    render: (_, row) => <span>应该支付：{row.should_pay_amount}<br/>实际支付：{row.pay_amount}</span>
  },
  {
    title: '支付方式',
    dataIndex: 'pay_type',
    search: true,
    valueEnum: () => {
      const enums = {}
      SELECTOR_PAY_TYPES.forEach(item => {
        enums[item.value] = {text: item.label}
      })
      return enums
    }
  },
  {
    title: '支付状态',
    dataIndex: 'status',
    valueEnum: {
      1: { text: '代缴' },
      2: { text: '支付中' },
      3: { text: '已支付' },
    },
    search: true
  },
  {
    title: '三方订单',
    dataIndex: 'transaction_id',
    search: false
  }
]
const _detailKeys = {
  "amount": "总费用",
  "bill_id": "账单id",
  "charge_desc": "费用描述",
  "charge_name": "费用名称",
  "charge_type": "费用类型",
  "current_used": "当前记录",
  "end": "结束时间",
  "last_used": "滞纳金",
  "late_fee": "滞纳金",
  "obj_name": "房间/车位/车牌",
  "start": "开始时间"
}

const PaymentBill:React.FC = () => {

  const [state, setState] = React.useState({
    visible: false,
    detailVisible: false
  })
  const [orderInfo, setOrderInfo] = React.useState({})

  const viewOrderDetail = async (row) => {
    const { data } = await GetChargeOrderInfo({ order_id: row.order_id })
    setOrderInfo(data?.[0])
    setState(prevState => ({ ...prevState, detailVisible: true }))
  }

  const columns2 = [{
    title: '操作',
    dataIndex: 'option',
    search: false,
	width: 210,
	align: 'center',
    render: (_, row, index, action) => {
      const buttons = [
        <a style={{marginRight: 20 }} onClick={() => {
          Modal.confirm({
            title: '确认收款',
            content: '你确定要将这条记录确认收款吗？',
            onOk: async () => {
              await ChargeOrderConfirm({ order_id: row.order_id })
              message.success('操作成功！')
              actionRef.current.reload()
            }
          })
        }}>确认收款</a>,
        <a style={{marginRight: 20 }} onClick={() => {
          viewOrderDetail(row)
          setState(prevState => ({
            ...prevState,
            visible: true
          }))
        }}>打印</a>,
        <a onClick={() => {
          viewOrderDetail(row)
        }}>详情</a>,
      ]
      if (row.status !== 2) buttons.shift()
      return buttons
    }
  }]

  const actionRef: any = React.useRef<ActionType>()

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        columns={columns.concat(columns2)}
        request={GetChargeOrderList}
        search={{ collapsed: false }}
        bordered
      />
      <Modal
        title="打印"
        width={300}
        visible={state.visible}
        zIndex={999}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
        onOk={() => {
          // @ts-ignore
          window.document.body.innerHTML = document.querySelector('.print-container').innerHTML as any
          window.print()
          window.location.reload()
        }}
      >
        <Select placeholder="打印类型" style={{ width: 200 }} options={[]} />
      </Modal>
      <Modal
        title="详情"
        visible={state.detailVisible}
        footer={false}
        zIndex={100}
        wrapClassName="print-container"
        onCancel={() => setState(prevState => ({ ...prevState, detailVisible: false }))}
      >
        <Form labelCol={{ span: 6 }} wrapperCol={{ span: 18 }}>
          {
            Object.keys(_detailKeys).map(key => (
              <Form.Item label={_detailKeys[key]}>
                { orderInfo[key] || '-' }
              </Form.Item>
            ))
          }
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default PaymentBill
