import React from 'react'
import { Button, Card, Divider, Form, Select, message } from "antd"
import { ChargeUrge } from "../../services/charge"

const ChargeSetting:React.FC = () => {
  const [urgeSetting, setUrgeSetting]: any = React.useState({})
  const [days, setDays] = React.useState([])
  const [form] = Form.useForm()

  React.useEffect(() => {
    const days = []
    for (let d = 1; d < 32; d++) {
      // @ts-ignore
      days.push({ label: `${d}日`, value: d })
    }
    setDays(days)
    getData()
  }, [])

  const getData = async () => {
    const { data } = await ChargeUrge({ method: 'get' })
    setUrgeSetting(data)
    form.setFieldsValue(data)
  }

  const onSave = () => {
    form.validateFields().then(values => {
      ChargeUrge({ method: 'put', ...values, id: urgeSetting.id })
      message.success('保存成功')
    })
  }

  return (
    <Card>
      <Divider />
      <Form labelCol={{ span: 2 }} wrapperCol={{ span: 18 }} form={form}>
        <Form.Item label="自动催缴日期" name="urge_day" rules={[{ required: true }]}>
          <Select style={{ width: 180 }} placeholder="请选择" options={days} />
        </Form.Item>
        <Form.Item label="tips">
          收费项目生成账单的当天8:30给住户推送缴费通知；<br/>若设置自动催缴日期后，则每月的日期当天9:30分默认给所有欠费房间中住户推送缴费通知。
        </Form.Item>
        <Form.Item label="自动催缴发送" name="urge_target" rules={[{ required: true }]}>
          <Select style={{ width: 180 }} placeholder="请选择" options={[
            { value: 1, label: '仅业主' },
            { value: 2, label: '业主和家人' },
            { value: 3, label: '业主家人租客' }
          ]} />
        </Form.Item>
        <Form.Item label="tips">
          自动催缴通知发送人，默认仅发给业主<br/>
          车位费对业主进行催缴，并且本系统只有业主可缴纳车位费
        </Form.Item>
        <Form.Item label="催缴方式" name="urge_msg_type" rules={[{ required: true }]}>
          <Select style={{ width: 180 }} placeholder="请选择" options={[
            { value: 1, label: '仅短信' },
            { value: 2, label: '仅微信' },
            { value: 3, label: '短信和微信' }
          ]} />
        </Form.Item>
      </Form>
      <Button type="primary" onClick={onSave}>保存</Button>
    </Card>
  )
}

export default ChargeSetting
