import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, Card, DatePicker, Select, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { GetChargeCar, ChargeBind, ChargeUnbind } from "../../services/entity"
import './index.scss'

const SetupBindRoom: React.FC = (props: any) => {
  const charge_id = +props.location.search.split('=')[1]
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'vehicle_id',
      search: false
    },
    {
      title: '车牌',
      dataIndex: 'plate_no',
      search: false,
    },
    {
      title: '车辆类型',
      dataIndex: 'vehicle_type',
      search: false,
    },
    {
      title: '停车开始时间',
      dataIndex: 'start',
      search: false,
    },
    {
      title: '停车结束时间',
      dataIndex: 'end',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a onClick={() => {
          Modal.confirm({
            title: '解除绑定?',
            content: '你确定解除绑定吗？',
            onOk: async () => {
              await ChargeUnbind({
                charge_id,
                obj_id: row.vehicle_id
              })
              message.success('操作成功')
              actionRef.current.reload()
            }
          })
        }}>移除</a>
      ]
    }
  ]
  const [state, setState] = React.useState({
    bindVisible: false
  })
  const [canBindCars, setCanBindCars] = React.useState([])

  React.useEffect(() => {
    GetChargeCar({
      bind: false,
      charge_id,
      page: 1,
      pageSize: 9999,
    }).then(({ data }) => {
      setCanBindCars(data)
    })
  }, [props.location.search])

  const actionRef: any = React.useRef<ActionType>()
  const [form]: any = Form.useForm()

  const handleBind = () => {
    form.validateFields().then(async (values) => {
      ['start', 'end'].forEach(key => {
        values[key] = values[key].valueOf()
      })
      await ChargeBind({
        charge_id: +props.location.search.split('=')[1],
        ...values
      })
      message.success('操作成功')
      actionRef.current?.reloadAndRest()
      setState(pre => ({ ...pre, bindVisible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        params={{
          charge_id: props.location.search.split('=')[1],
          bind: true
        }}
        search={false}
        request={GetChargeCar}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, bindVisible: true }))
            }}
          >
            <PlusOutlined /> 绑定车辆
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='收费车辆绑定'
        width={400}
        visible={state.bindVisible}
        onOk={handleBind}
        onCancel={() => setState(pre => ({ ...pre, bindVisible: false }))}
      >
        <div className={'mb-4'}>非必填，不填表示车辆剩余时间为0</div>
        <Form layout="vertical" form={form}>
          <Form.Item label='选择车辆' name="obj_ids" rules={[{ required: true }]}>
            <Select placeholder="请选择" mode="multiple">
              {
                canBindCars.map((item: any) => {
                  return (
                    <Select.Option value={item.vehicle_id}>
                      { item.plate_no }
                    </Select.Option>
                  )
                })
              }
            </Select>
          </Form.Item>
          <Form.Item label='停车开始时间（天）' name="start" rules={[{ required: true }]}>
            <DatePicker/>
          </Form.Item>
          <Form.Item label='停车结束时间（天）' name="end" rules={[{ required: true }]}>
            <DatePicker/>
          </Form.Item>
          <Form.Item label='自定义金额' name="custom_fee">
            <InputNumber placeholder="请输入"/>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(SetupBindRoom)