import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, Card, DatePicker, Select, message } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import { GetChargeHouse, ChargeBind, ChargeUnbind } from "../../services/entity"
import './index.scss'

const SetupBindRoom: React.FC = (props: any) => {
  const charge_id = +props.location.search.split('=')[1]
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'house_id',
      search: false
    },
    {
      title: '房号',
      dataIndex: 'house_number',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'house_type',
      search: false,
      valueEnum: {
        1: {
          text: '公寓'
        },
        2: {
          text: '住房'
        }
      },
    },
    {
      title: '建筑面积',
      dataIndex: 'house_area',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'house_used_area',
      search: false,
    },
    {
      title: '房屋状态',
      dataIndex: 'house_status',
      search: false,
      valueEnum: {
        1: { text: '未入驻' },
        2: { text: '未入驻' },
        3: { text: '已出租' },
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a onClick={() => {
          Modal.confirm({
            title: '解除绑定?',
            content: '你确定解除绑定这条记录吗？',
            onOk: async () => {
              await ChargeUnbind({
                charge_id,
                obj_id: row.house_id
              })
              message.success('操作成功')
              actionRef.current.reload()
            }
          })
        }}>移除</a>
      ]
    }
  ]
  const [state, setState] = React.useState({
    bindVisible: false
  })
  const [canBindHouse, setCanBindHouse] = React.useState([])

  React.useEffect(() => {
    GetChargeHouse({
      bind: false,
      charge_id,
      page: 1,
      pageSize: 9999,
    }).then(({ data }) => {
      setCanBindHouse(data)
    })
  }, [props.location.search])

  const actionRef: any = React.useRef<ActionType>()
  const [form]: any = Form.useForm()

  const handleBind = () => {
    form.validateFields().then(async (values) => {
      ['start'].forEach(key => {
        values[key] = values[key].valueOf()
      })
      await ChargeBind({
        charge_id: +props.location.search.split('=')[1],
        ...values
      })
      message.success('操作成功')
      actionRef.current?.reloadAndRest()
      setState(pre => ({ ...pre, bindVisible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        params={{
          charge_id,
          bind: true
        }}
        search={false}
        request={GetChargeHouse}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, bindVisible: true }))
            }}
          >
            <PlusOutlined /> 绑定房屋
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='收费房屋绑定'
        width={400}
        visible={state.bindVisible}
        onOk={handleBind}
        onCancel={() => setState(pre => ({ ...pre, bindVisible: false }))}
      >
        <Form layout="vertical" form={form}>
          <Form.Item label='选择房屋' name="obj_ids" rules={[{ required: true }]}>
            <Select placeholder="请选择" mode="multiple">
              {
                canBindHouse.map((item: any) => {
                  return (
                    <Select.Option value={item.house_id}>
                      { item.house_name }
                    </Select.Option>
                  )
                })
              }
            </Select>
          </Form.Item>
          <Form.Item label='账单开始计费时间（天）' name="start" rules={[{ required: true }]}>
            <DatePicker/>
          </Form.Item>
          <Form.Item label='自定义金额' name="custom_fee">
            <InputNumber placeholder="请输入"/>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(SetupBindRoom)