import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import {Button, Modal, Form, Input, Radio, Card, Table, Select, Divider, DatePicker} from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import './index.scss'

const rowSelection = {
  onChange: (selectedRowKeys: React.Key[], selectedRows: any[]) => {
    console.log(`selectedRowKeys: ${selectedRowKeys}`, 'selectedRows: ', selectedRows);
  },
  getCheckboxProps: (record: any) => ({
    disabled: record.name === 'Disabled User', // Column configuration not to be checked
    name: record.name,
  }),
};

const SetupBindRoom: React.FC = (props: any) => {

  const [selectionType, setSelectionType] = React.useState<'checkbox' | 'radio'>('checkbox');

  const roomColumns:any = [
    {
      title: '房屋',
      dataIndex: 'id',
      search: false
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      render: (_, row, index, action) => [
        <div>已绑定</div>
      ]
    }
  ]
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '房号',
      dataIndex: 'name',
      search: false,
    },
    {
      title: '楼层',
      dataIndex: 'name',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'name',
      search: false,
      valueEnum: {
        1: {
          text: '公寓'
        },
        2: {
          text: '住房'
        }
      },
    },
    {
      title: '建筑面积',
      dataIndex: 'name',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'name',
      search: false,
    },
    {
      title: '房屋状态',
      dataIndex: 'name',
      search: false,
      valueEnum: {
        1: {
          text: '已入驻'
        },
        2: {
          text: '未入驻'
        }
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a onClick={() => {
          Modal.confirm({
            title: '确认删除这条记录吗?',
            content: '你确定删除这条记录吗？',
            onOk() {},
            onCancel() {}
          })
        }}>移除</a>
      ]
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    bindVisible: false
  })

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={() => {
          return Promise.resolve({
            total: 200,
            data: [{}],
            success: true,
          });
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
            }}
          >
            <PlusOutlined /> 添加房间
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='添加房屋绑定'
        visible={state.visible}
        width={750}
        onOk={() => setState(pre => ({ ...pre, bindVisible: true }))}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        okText={'绑定'}
      >
        <div className={'flex items-center'}>
          <Select style={{ width: '100px' }} placeholder={'楼栋'}/>
          <Select style={{ width: '100px' }} placeholder={'单元'}/>
          <Select style={{ width: '100px' }} placeholder={'楼层'}/>
          <Divider type={'vertical'}  />
          <Button type={'primary'}>搜索</Button>
        </div>
        <Divider />
        <div className={'mb-2'}>
          <Button
            size={'small'}
            type={'primary'}
            onClick={() => setState(pre => ({ ...pre, bindVisible: true }))}
          >批量绑定</Button>
        </div>
        <Table
          rowSelection={{
            type: selectionType,
            ...rowSelection,
          }}
          pagination={{
            pageSize: 10,
            current: 1
          }}
          dataSource={[{}, {}]}
          columns={roomColumns}
          bordered
        >

        </Table>
      </Modal>
      <Modal
        title='收费房屋绑定'
        visible={state.bindVisible}
        width={400}
        onOk={() => setState(pre => ({ ...pre, bindVisible: false }))}
        onCancel={() => setState(pre => ({ ...pre, bindVisible: false }))}
      >
        <Form
          labelCol={{ span: 10 }}
          wrapperCol={{ span: 14 }}
        >
          <Form.Item label='账单开始计费时间'>
            <DatePicker.MonthPicker placeholder={'选择月份'} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(SetupBindRoom)