import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, Card, DatePicker, Avatar, message } from 'antd'
import { PlusOutlined, CarOutlined, HomeOutlined, ClockCircleOutlined } from '@ant-design/icons'
import { withRouter } from 'react-router-dom'
import TypeForm, { formTypes, LateFee } from "./type-form"
import { ChargeConfig, CreateChargeBill } from "../../services/charge"
import { CHARGE_TYPES } from "../../CONSTANT"
import moment from 'moment'
import './index.scss'

const bindTypeStyle = { display: 'flex', alignItems: 'center', justifyContent: 'center' }
const Avatar2: any = Avatar

const ChargeSetup: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '费用类型',
      dataIndex: 'charge_type',
      // 物业费 2 水费 3 电费 4 气费 5 车位管理费 6 月租停车费 99 其他
      search: false,
      valueEnum: CHARGE_TYPES,
    },
    {
      title: '费项名称',
      dataIndex: 'charge_name',
      search: false
    },
    {
      title: '费用方式',
      dataIndex: 'charge_time_type',
      search: false,
      valueEnum: {
        1: { text: '周期性缴' },
        2: { text: '一次性' }
      }
    },
    {
      title: '账单生成周期',
      dataIndex: 'bill_period',
      search: false,
      valueEnum: {
        1: {
          text: '月份'
        },
        2: {
          text: '季度'
        },
        3: {
          text: '半年'
        },
        4: {
          text: '年'
        },
      }
    },
    {
      title: '收费方式',
      dataIndex: 'charge_basis',
      search: false,
      valueEnum: {
        1: { text: '按房屋面积' },
        2: { text: '按使用面积' },
        3: { text: '按车位面积' },
        4: { text: '按使用量' },
        5: { text: '固定费用' },
        6: { text: '自定义' }
      }
    },
    {
      title: '计费单位（单位：元）',
      dataIndex: 'unit_price',
      search: false,
    },
    {
      title: '附加/固定费用（单位：元）',
      dataIndex: 'fix_amount',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <div className='controller-group'>
          <a style={{marginRight: 20 }} onClick={() => {
            setState(prevState => ({
              ...prevState,
              bindVisible: true
            }))
            setEditRow(row)
          }}>绑定</a>
          <a style={{marginRight: 20 }} onClick={() => {
            setState((prevState => ({
              ...prevState,
              visible: true
            })))
            row.charge_effective_time = moment(row.charge_effective_time)
            setEditRow(row)
            form.setFieldsValue(row)
          }}>编辑</a>
          <a onClick={() => {
            Modal.confirm({
              title: '确认删除这条记录吗?',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await ChargeConfig({ method: 'delete', id: row.id })
                message.success('操作成功')
                actionRef.current.reload()
              }
            })
          }}>删除</a>
          {/*{*/}
          {/*  (row.charge_time_type === 1 || [2, 3, 4].includes(row.charge_type)) && <Button onClick={() => {*/}
          {/*    setState(prevState => ({*/}
          {/*      ...prevState,*/}
          {/*      billVisible: true*/}
          {/*    }))*/}
          {/*  }}>生成账单</Button>*/}
          {/*}*/}
        </div>
      ]
    }
  ]
  const actionRef = React.useRef<ActionType>() as any
  const [form] = Form.useForm()
  // edit
  const [editRow, setEditRow] = React.useState({}) as any
  const [state, setState] = React.useState({
    visible: false,
    exportVisible: false,
    billVisible: false,
    bindVisible: false,
    currentFormType: 1
  })


  const [billDateRange, setBillDateRange]: any = React.useState([])
  const handleCreateBill = async () => {
    if (!billDateRange.length) return message.error('未选择日期')
    setState(pre => ({ ...pre, billVisible: false }))
    await CreateChargeBill({
      charge_id: editRow.id,
      end: billDateRange[1].valueOf()
    })
    message.success('操作成功！')
  }

  const onSubmit = () => {
    console.log(form.getFieldsValue())
    form.validateFields().then(async values => {
      if (values['charge_effective_time']) {
        values['charge_effective_time'] = values['charge_effective_time'].valueOf()
      }
      ['fix_amount', 'unit_price'].forEach(key => {
        values[key] = +parseInt(values[key]).toFixed(0)
      })
      await ChargeConfig({ method: editRow.id ? 'put' : 'post', ...values, id: editRow.id })
      message.success('操作成功')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(pre => ({ ...pre, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <Card className='charge-filter' style={{ marginBottom: 16 }}>
        <Input style={{ width: 240 }} placeholder='请输入楼栋编号' />
        <Button type='primary' style={{ marginLeft: 12 }}>搜索</Button>
      </Card>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={ChargeConfig}
        bordered={true}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setEditRow({})
              setState(preState => ({ ...preState, visible: true }))
            }}
          >
            <PlusOutlined /> 添加
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title='绑定类型'
        width={440}
        visible={state.bindVisible}
        onOk={() => setState(pre => ({ ...pre, bindVisible: false }))}
        onCancel={() => setState(pre => ({ ...pre, bindVisible: false }))}
        footer={false}
      >
        <div className={'flex justify-center items-center'}>
          {
            editRow.charge_type !== 99 && [5, 6].includes(editRow.charge_type) && (
              <Avatar2
                style={{ ...bindTypeStyle, marginRight: '30px' }}
                shape="square"
                size={100}
                icon={<ClockCircleOutlined />}
                onClick={() => {
                  props.history.push(`/admin/charge/setup-parking?charge_id=${editRow.id}`)
                }}
              />
            )
          }
          {
            editRow.charge_type !== 99 && [5, 6].includes(editRow.charge_type) && (
              <Avatar2
                style={{ ...bindTypeStyle, marginRight: '30px' }}
                shape="square"
                size={100}
                icon={<CarOutlined />}
                onClick={() => {
                  props.history.push(`/admin/charge/setup-car?charge_id=${editRow.id}`)
                }}
              />
            )
          }
          {
            ![5, 6].includes(editRow.charge_type) && (
              <Avatar2
                style={ bindTypeStyle }
                shape="square"
                size={100}
                icon={<HomeOutlined />}
                onClick={() => {
                  props.history.push(`/admin/charge/setup-room?charge_id=${editRow.id}`)
                }}
              />
            )
          }
        </div>
      </Modal>
      <Modal
        title='生成账单'
        width={340}
        visible={state.billVisible}
        onOk={handleCreateBill}
        onCancel={() => setState(pre => ({ ...pre, billVisible: false }))}
      >
        <div className={'mb-2'}>选择日期范围</div>
        <DatePicker.RangePicker onChange={(values) => {
          setBillDateRange(values)
        }} />
      </Modal>
      <Modal
        title={editRow ? '编辑费用设置' : '添加费用设置'}
        visible={state.visible}
        width={680}
        maskClosable={false}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{  span: 15 }}
          form={form}
        >
          <div className='form-subtitle'>基本设置</div>
          <Form.Item label='费用类型' name="charge_type" rules={[{ required: true }]}>
            <Select
              placeholder='请选择'
              options={formTypes}
              onChange={(value) => {
                // @ts-ignore
                setState(prevState => ({
                  ...prevState,
                  currentFormType: value
                }))
              }}
            />
          </Form.Item>
          <Form.Item label='费项名称' name="charge_name" rules={[{ required: true }]}>
            <Input placeholder='单行输入'/>
          </Form.Item>
          <Form.Item label='收费方式' name="charge_basis" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '按房屋面积', value: 1 },
              { label: '按使用面积', value: 2 },
              { label: '按车位面积', value: 3 },
              { label: '按使用量测试', value: 4 },
              { label: '固定费用', value: 5 },
              { label: '自定义定费用', value: 6 },
            ]}/>
          </Form.Item>
          { TypeForm[[2, 3, 4].includes(state.currentFormType) ? 2 : state.currentFormType]() }
          {
            state.currentFormType !== 6 && <React.Fragment>
              <div className={'form-subtitle'}> 滞纳金设置</div>
              <LateFee />
            </React.Fragment>
          }
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeSetup)