import React from 'react'
import ProTable, {ActionType} from "@ant-design/pro-table"
import {Button, message, Modal, Input} from "antd"
import { GetUnPayBill, GetUnPayBillDetails, UnPayBillDiscard, ChargeUnPayBillUrge } from '../../services/charge'
import { CHARGE_TYPES } from "../../CONSTANT"
import {Car} from "../../services/parking";

const columns: any = [
  {
    title: '房间/车位',
    dataIndex: 'obj_name',
    search: false,
  },
  {
    title: '住户号',
    dataIndex: 'id',
    hideInTable: true,
    search: true,
  },
  {
    title: '住户电话',
    dataIndex: 'id',
    hideInTable: true,
    search: true,
  },
  {
    title: '账单数',
    dataIndex: 'bill_count',
    search: false
  },
  {
    title: '合计',
    dataIndex: 'should_pay_amount',
    search: false
  }
]
const detailColumns: any = [
  {
    title: '费用类型',
    dataIndex: 'charge_type',
    search: false,
    valueEnum: CHARGE_TYPES
  },
  {
    title: '费项名称',
    dataIndex: 'charge_name',
    search: false,
  },
  {
    title: '应收金额',
    dataIndex: 'amount',
    search: false,
  },
  {
    title: '滞纳金',
    dataIndex: 'late_fee',
    search: false,
  },
  {
    title: '账单开始时间',
    dataIndex: 'start',
    search: false,
  },
  {
    title: '账单结束时间',
    dataIndex: 'end',
    search: false,
  },
  {
    title: '上次读数',
    dataIndex: 'last_used',
    search: false,
  },
  {
    title: '本次读数',
    dataIndex: 'current_used',
    search: false,
  }
]

const ShouldBill:React.FC = () => {

  const [state, setState] = React.useState({ visible: false, confirmVisible: false, editId: null })
  const [rowData, setRowData]: any = React.useState({})
  const [delReason, setDelReason]: any = React.useState(null)

  const optionsColumn = {
    title: '操作',
    dataIndex: 'option',
    search: false,
	width:210,
	align: 'center',
    render: (_, row, index, action) => [
      <a  style={{marginRight: 20 }} onClick={() => {
        setRowData(row)
        setState(prevState => ({
          ...prevState,
          visible: true
        }))
      }}>应收明细</a>,
      <a onClick={() => {
        Modal.confirm({
          title: '催缴',
          content: '你确定催缴这条记录吗？',
          onOk: async () => {
            await ChargeUnPayBillUrge({
              obj_id: row.obj_id,
              obj_type: row.obj_type
            })
            message.success('操作成功！')
            actionPrimaryRef.current.reload()
          }
        })
      }}>一键催缴</a>
    ]
  }
  const detailOptionColumn = {
    title: '操作',
    dataIndex: 'option',
    search: false,
	width:210,
	align: 'center',
    render: (_, row, index, action) => [
      <a type="link" onClick={() => {
        setState(prevState => ({ ...prevState, confirmVisible: true, editId: row.bill_id }))
      }}>作废账单</a>
    ]
  }

  const actionRef: any = React.useRef<ActionType>()
  const actionPrimaryRef: any = React.useRef<ActionType>()

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionPrimaryRef}
        columns={[ ...columns, optionsColumn ]}
        request={GetUnPayBill}
        toolBarRender={() => [
          <Button type="primary" onClick={() => {
            setState(prevState => ({
              ...prevState,
              visible: true
            }))
          }}>批量催缴</Button>
        ]}
        bordered
      />
      <Modal
        title="应收明细"
        visible={state.visible}
        width={1500}
        onOk={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
        onCancel={() => setState(prevState => ({
          ...prevState,
          visible: false
        }))}
        destroyOnClose
      >
        <ProTable
          search={false}
          toolBarRender={false}
          columns={[...detailColumns, detailOptionColumn]}
          actionRef={actionRef}
          params={{
            obj_id: rowData.obj_id,
            obj_type: rowData.obj_type
          }}
          bordered
          request={GetUnPayBillDetails}
        />
      </Modal>
      <Modal
        title="确认作废账单"
        visible={state.confirmVisible}
        width={400}
        onOk={async () => {
          if (!delReason) return message.error('作废原因为空！')
          await UnPayBillDiscard({
            bill_id: state.editId,
            del_reason: delReason
          })
          setState(prevState => ({ ...prevState, confirmVisible: false }))
          message.success('操作成功！')
          actionRef.current.reload()
        }}
        onCancel={() => setState(prevState => ({
          ...prevState,
          confirmVisible: false
        }))}
        destroyOnClose
      >
        <Input.TextArea
          onChange={($event) => setDelReason($event.target.value)}
          rows={4}
          placeholder="请输入"
        />
      </Modal>
    </React.Fragment>
  )
}

export default ShouldBill
