import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select, Upload } from 'antd'
import { withRouter } from 'react-router-dom'
import { ComplaintApi, ComplaintOrderSend } from '../../services/complaint'
import './index.scss'
import { PlusOutlined } from "@ant-design/icons"
import { useUser } from "../User/hooks"

const ComplaintPage: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '投诉类型',
      dataIndex: 'suggestion_type',
      search: true,
      valueEnum: {
        1: { text: '投诉' },
        2: { text: '建议' }
      }
    },
    {
      title: '投诉人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '投诉内容',
      dataIndex: 'apply_content',
      search: false,
    },
    {
      title: '投诉日期',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      valueEnum: {
        1: { text: '未派单' },
        2: { text: '已派单' },
        3: { text: '已完结' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        const DETAIL_BUTTON = <a
		  style={{marginRight: 20 }}
          className="mr-1.5"
          onClick={() => {
            props.history.push(`/admin/complaint/detail?id=${row.id}`)
          }}
        >详情</a>
        return ['已派单', '已完结'].includes(row.status) ? DETAIL_BUTTON : [
          <a style={{marginRight: 20 }}
            className="mr-1.5"
            onClick={() => {
              form.setFieldsValue(row)
              setPic(row.apply_pic.map(url => ({
                thumbUrl: url,
                response: { data: url }
              })))
              setState(prevState => ({
                ...prevState,
                visible: true,
                editId: row.id
              }))
            }}
          >编辑</a>,
          <Button
            className="mr-1.5"
            onClick={() => {
              setState(prevState => ({
                ...prevState,
                orderVisible: true,
                editId: row.id
              }))
            }}
          >派单</Button>,
          <Button
            className="mr-1.5"
            onClick={() => {
              props.history.push(`/admin/complaint/detail?id=${row.id}`)
            }}
          >详情</Button>,
          <Button onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await ComplaintApi({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</Button>
        ]
      }
    }
  ]

  const [pic, setPic]: any = React.useState([])
  const [cUsers, setUsers]: any = useUser()

  React.useEffect(() => {
    setUsers()
  }, [])

  const uploadButton = (
    <div>
      <PlusOutlined />
      <div style={{ marginTop: 8 }}>上传图片</div>
    </div>
  )
  const [state, setState] = React.useState({
    visible: false,
    orderVisible: false,
    editId: null
  })

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()

  const onSubmit = () => {
    form.validateFields().then(async values => {
      await ComplaintApi({
        method: 'post',
        ...values,
        apply_pic: pic.map(({ response }) => response.data),
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  const [orderForm] = Form.useForm()
  const handleSendOrder = () => {
    orderForm.validateFields().then(async values => {
      await ComplaintOrderSend({ ...values, id: state.editId, current_uid: 1 })
      message.success('操作成功！')
      orderForm.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={ComplaintApi}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='派单'
        visible={state.orderVisible}
        onOk={handleSendOrder}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          <Form.Item label='处理对象' name="current_uid" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={cUsers} />
          </Form.Item>
          <Form.Item label='处理意见' name="feedback" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='添加投诉/建议'
        visible={state.visible}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='投诉类型' name="suggestion_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '投诉', value: 1 },
              { label: '建议', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='投诉人' name="apply_people" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='联系方式' name="apply_people_phone" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='投诉内容' name="apply_content" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
          <Form.Item label='投诉图片' name="apply_pic" rules={[{ required: false }]}>
            <Upload
              action="http://localhost:3000/api/v1/upload"
              listType="picture-card"
              fileList={pic}
              onChange={(({ fileList }) => setPic(fileList))}
            >
              { uploadButton }
            </Upload>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ComplaintPage)