import React from "react";
import { Button, Card, Divider, Form, Table, Col, Row, Image } from "antd";
import { useHistory } from "react-router";
import { GetComplaintInfo } from "../../services/complaint";

const columns = [
  {
    title: "ID",
    dataIndex: "id"
  },
  {
    title: "处理人",
    dataIndex: "user"
  },
  {
    title: "状态",
    dataIndex: "status"
  },
  {
    title: "处理时间",
    dataIndex: "handle_time"
  },
  {
    title: "意见",
    dataIndex: "feedback"
  }
];
const infoKeys = [
  { label: "投诉类型", key: "suggestion_type" },
  { label: "联系人", key: "apply_people" },
  { label: "联系方式", key: "apply_people_phone" },
  { label: "投诉内容", key: "apply_content" },
  { label: "投诉图片", key: "", col: 24, type: "picture" }
];

const OrderDetail: React.FC = () => {
  const history: any = useHistory();
  const [orderInfo, setOrderInfo]: any = React.useState({
    base_info: {
      apply_pic: []
    }
  });

  const statusItems = { 1: "投诉", 2: "建议" };
  const visitLevel = { 1: "满意", 2: "不满意" };

  React.useEffect(() => {
    GetComplaintInfo(history.location.search).then((res: any) => {
      res.base_info.suggestion_type =
        statusItems[res.base_info.suggestion_type];
      setOrderInfo(res);
    });
  }, []);

  return (
    <React.Fragment>
      <div
        className="flex justify-between items-center pb-3"
        style={{ fontSize: "18px" }}
      >
        <div
          style={{
            display: "flex",
            justifyContent: "flex-end",
            marginBottom: 20
          }}
        >
          <Button style={{ marginRight: 10,borderRadius:"5px" }} className="mr-1.5" type="primary">
            打印
          </Button>
          <Button style={{borderRadius:"5px" }} onClick={() => history.goBack()}>返回</Button>
        </div>
      </div>
      <Card title="工单详情">
        <Form>
          <Row>
            {infoKeys.map((item) => (
              <Col span={item.col || 8}>
                <Form.Item label={item.label}>
                  {item.type === "picture"
                    ? orderInfo.base_info.apply_pic.map((url) => (
                        <Image width={100} src={url} />
                      ))
                    : orderInfo?.base_info[item.key]}
                </Form.Item>
              </Col>
            ))}
          </Row>
        </Form>
      </Card>
      <Divider />
      <Card title="工单流转">
        <Table dataSource={orderInfo.list} columns={columns} bordered />
      </Card>
      <Divider />
      <Card title="回访/业主评价">
        <Form>
          <Form.Item label="满意度">
            {visitLevel[orderInfo.base_info?.return_visit_level] || "暂无"}
          </Form.Item>
          <Form.Item label="业主评价">
            {orderInfo.base_info?.return_visit_content || "暂无评价"}
          </Form.Item>
        </Form>
      </Card>
    </React.Fragment>
  );
};

export default OrderDetail;
