import React, { useRef } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select } from 'antd'
import { withRouter } from 'react-router-dom'
import { ComplaintOrderReturnVisit, ComplaintApi } from '../../services/complaint'
import './index.scss'

const ComplaintReturnVisit: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '投诉类型',
      dataIndex: 'suggestion_type',
      search: true,
      valueEnum: {
        1: { text: '投诉' },
        2: { text: '建议' }
      }
    },
    {
      title: '投诉人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '投诉内容',
      dataIndex: 'apply_content',
      search: false,
    },
    {
      title: '投诉日期',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      valueEnum: {
        1: { text: '未派单' },
        2: { text: '已派单' },
        3: { text: '已完结' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a style={{marginRight: 20 }}
            className="mr-1.5"
            onClick={() => {
              setState(prevState => ({
                ...prevState,
                orderVisible: true,
                editId: row.id
              }))
            }}
          >回访</a>,
          <a
            className="mr-1.5"
            onClick={() => props.history.push(`/admin/complaint/detail?id=${row.id}`)}
          >详情</a>,
        ]
      }
    }
  ]

  const [state, setState] = React.useState({
    orderVisible: false,
    editId: null,
    formMode: 'send'
  })

  const actionRef: any = useRef<ActionType>()
  const [orderForm] = Form.useForm()

  const onSubmit = () => {
    orderForm.validateFields().then(async values => {
      await ComplaintOrderReturnVisit({ ...values, id: state.editId })
      message.success('操作成功！')
      orderForm.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={ComplaintApi}
        params={{ status: 3 }}
        columns={columns}
      />
      <Modal
        title='投诉回访'
        visible={state.orderVisible}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          <Form.Item label='满意度' name="return_visit_level" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={[
              { label: '满意', value: 1 },
              { label: '不满意', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='业主评价' name="return_visit_content" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ComplaintReturnVisit)