import React from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import {
  Button,
  Modal,
  Form,
  Input,
  message,
  Select,
  DatePicker,
  Upload
} from "antd";
import { withRouter } from "react-router-dom";
import { FixApi, FixOrderSend } from "../../services/fix";
import "./index.scss";
import { PlusOutlined } from "@ant-design/icons";
import { useFixClass } from "./hooks";
import { useBuildingHouse } from "../building/hooks";
import { useUser } from "../User/hooks";
import { GetTimeStamp } from "../../utils";
import moment from "moment";

const FixOnlineForm: React.FC = (props: any) => {
  const columns: any = [
    {
      title: "ID",
      dataIndex: "id",
      search: false
    },
    {
      title: "分类名称",
      dataIndex: "class_name",
      search: true
    },
    {
      title: "联系地址",
      dataIndex: "house_name",
      search: false
    },
    {
      title: "报修人",
      dataIndex: "apply_people",
      search: true
    },
    {
      title: "联系电话",
      dataIndex: "apply_people_phone",
      search: true
    },
    {
      title: "预约时间",
      dataIndex: "appointment",
      search: false,
      valueType: "dateTime"
    },
    {
      title: "报修内容",
      dataIndex: "apply_content",
      search: false
    },
    {
      title: "报修时间",
      dataIndex: "created_at",
      search: false,
      valueType: "dateTime"
    },
    {
      title: "状态",
      dataIndex: "status",
      search: true,
      valueEnum: {
        1: { text: "未派单" },
        2: { text: "已派单" },
        3: { text: "已完结" }
      }
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      width: 210,
      align: "center",
      render: (_, row, index, action) => {
        const DETAIL_BUTTON = (
          <a
            style={{ marginRight: 20 }}
            className="mr-1.5"
            onClick={() => {
              props.history.push(`/admin/fix/order-detail?id=${row.id}`);
            }}
          >
            详情
          </a>
        );
        return ["已派单", "已完结"].includes(row.status)
          ? DETAIL_BUTTON
          : [
              <a
                style={{ marginRight: 20 }}
                className="mr-1.5"
                onClick={() => {
                  row.appointment = moment(row.appointment);
                  form.setFieldsValue(row);
                  setPic(
                    row.apply_pic.map((url) => ({
                      thumbUrl: url,
                      response: { data: url }
                    }))
                  );
                  setState((prevState) => ({
                    ...prevState,
                    visible: true,
                    editId: row.id
                  }));
                }}
              >
                编辑
              </a>,
              <a
                style={{ marginRight: 20 }}
                className="mr-1.5"
                onClick={() => {
                  setState((prevState) => ({
                    ...prevState,
                    orderVisible: true,
                    editId: row.id
                  }));
                }}
              >
                派单
              </a>,
              DETAIL_BUTTON,
              <a
                onClick={() => {
                  Modal.confirm({
                    title: "删除记录",
                    content: "你确定删除这条记录吗？",
                    onOk: async () => {
                      await FixApi({ method: "delete", id: row.id });
                      message.success("操作成功！");
                      actionRef.current.reload();
                    }
                  });
                }}
              >
                删除
              </a>
            ];
      }
    }
  ];

  const [pic, setPic]: any = React.useState([]);
  const [fixClass, setFixClass] = useFixClass();
  const [buildHouse, setBuildHouse]: any = useBuildingHouse();
  const [cUsers, setUsers]: any = useUser();

  React.useEffect(() => {
    setFixClass();
    setBuildHouse();
    setUsers();
  }, []);

  const uploadButton = (
    <div>
      <PlusOutlined />
      <div style={{ marginTop: 8 }}>上传图片</div>
    </div>
  );
  const [state, setState] = React.useState({
    visible: false,
    orderVisible: false,
    editId: null
  });

  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const [orderForm] = Form.useForm();

  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      await FixApi({
        method: state.editId ? "put" : "post",
        ...values,
        apply_pic: pic.map(({ response }) => response.data),
        appointment: GetTimeStamp(values.appointment),
        id: state.editId
        // garden_id: 3,
      });
      message.success("操作成功！");
      form.resetFields();
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false, editId: null }));
    });
  };

  const handleSendOrder = () => {
    orderForm.validateFields().then(async (values) => {
      await FixOrderSend({ ...values, id: state.editId, current_uid: 1 });
      message.success("操作成功！");
      orderForm.resetFields();
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({
        ...prevState,
        orderVisible: false,
        editId: null
      }));
    });
  };

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={FixApi}
        toolBarRender={() => [
          <Button
            style={{ borderRadius: "5px" }}
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields();
              setPic([]);
              setState((preState) => ({
                ...preState,
                visible: true,
                editId: null
              }));
            }}
          >
            添加
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title="派单"
        visible={state.orderVisible}
        onOk={handleSendOrder}
        onCancel={() => setState((pre) => ({ ...pre, orderVisible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={orderForm}>
          <Form.Item
            label="报修师傅"
            name="current_uid"
            rules={[{ required: true }]}
          >
            <Select placeholder="请选择" options={cUsers} />
          </Form.Item>
          <Form.Item
            label="处理意见"
            name="feedback"
            rules={[{ required: true }]}
          >
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title={state.editId ? "编辑报修" : "添加报修"}
        visible={state.visible}
        onOk={onSubmit}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item
            label="报修分类"
            name="class_id"
            rules={[{ required: true }]}
          >
            <Select placeholder="请选择" options={fixClass} />
          </Form.Item>
          <Form.Item
            label="报修人"
            name="apply_people"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="联系方式"
            name="apply_people_phone"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="预约时间"
            name="appointment"
            rules={[{ required: true }]}
          >
            <DatePicker
              showTime
              placeholder="选择时间"
              format="YYYY-MM-DD HH:mm"
            />
          </Form.Item>
          <Form.Item
            label="报修内容"
            name="apply_content"
            rules={[{ required: true }]}
          >
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
          <Form.Item
            label="报修图片"
            name="apply_pic"
            rules={[{ required: true }]}
          >
            <Upload
              action="http://localhost:3000/api/v1/upload"
              listType="picture-card"
              fileList={pic}
              onChange={({ fileList }) => setPic(fileList)}
            >
              {uploadButton}
            </Upload>
          </Form.Item>
          <Form.Item label="区域" name="area" rules={[{ required: true }]}>
            <Select
              placeholder="请选择"
              options={[
                { label: "公共区域", value: 1 },
                { label: "室内", value: 2 }
              ]}
            />
          </Form.Item>
          <Form.Item
            label="联系地址"
            name="house_id"
            rules={[{ required: true }]}
          >
            <Select placeholder="请选择" options={buildHouse} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(FixOnlineForm);
