import React from "react";
import { Button, Card, Divider, Form, Table, Col, Row, Image } from "antd";
import { useHistory } from "react-router";
import { GetFixOrderInfo } from "../../services/fix";

const columns = [
  {
    title: "ID",
    dataIndex: "id"
  },
  {
    title: "处理人",
    dataIndex: "user"
  },
  {
    title: "状态",
    dataIndex: "status"
  },
  {
    title: "处理时间",
    dataIndex: "handle_time"
  },
  {
    title: "意见",
    dataIndex: "feedback"
  }
];
const infoKeys = [
  { label: "分类名称", key: "class_name" },
  { label: "联系地址", key: "house_name" },
  { label: "报修人", key: "apply_people" },
  { label: "联系方式", key: "apply_people_phone" },
  { label: "预约时间", key: "appointment" },
  { label: "报修时间", key: "created_at" },
  { label: "报修内容", key: "apply_content" },
  { label: "报修图片", key: "", col: 24, type: "picture" }
];

const OrderDetail: React.FC = () => {
  const history = useHistory();
  const [orderInfo, setOrderInfo]: any = React.useState({
    base_info: {
      apply_pic: []
    }
  });
  const visitLevel = {
    1: "满意",
    2: "不满意"
  };

  React.useEffect(() => {
    GetFixOrderInfo(history.location.search).then((res) => {
      setOrderInfo(res);
    });
  }, []);

  React.useEffect(() => {
    console.log(orderInfo.base_info.apply_pic);
  });

  return (
    <div className="print-container">
      <div
        className="flex justify-between items-center pb-3"
        style={{ fontSize: "18px" }}
      >
        <div
          style={{
            display: "flex",
            justifyContent: "flex-end",
            marginBottom: 20
          }}
        >
          <Button
            style={{ marginRight: 10,borderRadius:"5px" }}
            className="mr-1.5"
            type="primary"
            onClick={() => {
              // @ts-ignore
              window.document.body.innerHTML = document.querySelector(
                ".print-container"
              ).innerHTML as any;
              window.print();
              window.location.reload();
            }}
          >
            打印
          </Button>
          <Button style={{borderRadius:"5px" }} onClick={() => history.goBack()}>返回</Button>
        </div>
      </div>
      <Card title="工单详情">
        <Form>
          <Row>
            {infoKeys.map((item) => (
              <Col span={item.col || 8}>
                <Form.Item label={item.label}>
                  {item.type === "picture"
                    ? orderInfo.base_info.apply_pic.map((url) => (
                        <Image width={100} src={url} />
                      ))
                    : orderInfo?.base_info[item.key]}
                </Form.Item>
              </Col>
            ))}
          </Row>
        </Form>
      </Card>
      <Divider />
      <Card title="工单流转">
        <Table dataSource={orderInfo.list} columns={columns} bordered />
      </Card>
      <Divider />
      <Card title="回访/业主评价">
        <Form>
          <Form.Item label="满意度">
            {visitLevel[orderInfo.base_info?.return_visit_level] || "暂无"}
          </Form.Item>
          <Form.Item label="业主评价">
            {orderInfo.base_info?.return_visit_content || "暂无评价"}
          </Form.Item>
        </Form>
      </Card>
    </div>
  );
};

export default OrderDetail;
