import React, { useRef } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, message, Select } from 'antd'
import { withRouter } from 'react-router-dom'
import { FixOrderReturnVisit, FixApi } from '../../services/fix'
import './index.scss'

const FixReturnVisit: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '分类名称',
      dataIndex: 'class_name',
      search: true,
    },
    {
      title: '联系地址',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '报修人',
      dataIndex: 'apply_people',
      search: true,
    },
    {
      title: '联系电话',
      dataIndex: 'apply_people_phone',
      search: true,
    },
    {
      title: '预约时间',
      dataIndex: 'appointment',
      search: false,
      valueType: 'dateTime',
    },
    {
      title: '报修内容',
      dataIndex: 'apply_content',
      search: false,
    },
    {
      title: '报修时间',
      dataIndex: 'created_at',
      search: false,
      valueType: 'dateTime',
    },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      valueEnum: {
        1: { text: '未派单' },
        2: { text: '已派单' },
        3: { text: '已完结' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a
		    style={{marginRight: 20 }}
            className="mr-1.5"
            onClick={() => {
              orderForm.setFieldsValue(row)
              setState(prevState => ({
                ...prevState,
                formMode: 'send',
                orderVisible: true,
                editId: row.id
              }))
            }}
          >回访</a>,
          <a
            className="mr-1.5"
            onClick={() => {
              props.history.push(`/admin/fix/order-detail?id=${row.id}`)
            }}
          >详情</a>,
        ]
      }
    }
  ]

  const [state, setState] = React.useState({
    orderVisible: false,
    editId: null,
    formMode: 'send'
  })

  const actionRef: any = useRef<ActionType>()
  const [orderForm] = Form.useForm()

  const onSubmit = () => {
    orderForm.validateFields().then(async values => {
      await FixOrderReturnVisit({ ...values, id: state.editId })
      message.success('操作成功！')
      orderForm.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, orderVisible: false, editId: null }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={FixApi}
        params={{ status: 3 }}
        columns={columns}
      />
      <Modal
        title='报修回访'
        visible={state.orderVisible}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, orderVisible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={orderForm}
        >
          <Form.Item label='满意度' name="return_visit_level" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={[
              { label: '满意', value: 1 },
              { label: '不满意', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='业主评价' name="return_visit_content" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(FixReturnVisit)