import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Radio, Input, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { FixClassApi } from '../../services/fix'
import './index.scss'

const FixTypes: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '分类名称',
      dataIndex: 'name',
      search: true,
    },
    {
      title: '状态',
      dataIndex: 'enable',
      search: false,
      valueEnum: {
        true: { text: '开启', status: 'Success' },
        false: { text: '关闭', status: 'Error' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a
		    style={{marginRight: 20 }}
            className="mr-1.5"
            onClick={() => {
              form.setFieldsValue(row)
              setState(prevState => ({
                ...prevState,
                visible: true,
                editId: row.id
              }))
            }}
          >编辑</a>,
          <a onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await FixClassApi({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await FixClassApi({
        method: state.editId ? 'put' : 'post',
        ...values,
        id: state.editId
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false, editId: null }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={FixClassApi}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='添加分类'
        visible={state.visible}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='分类名称' name="name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='分类状态' name="enable" rules={[{ required: true }]}>
            <Radio.Group>
              <Radio value={true}>开启</Radio>
              <Radio value={false}>关闭</Radio>
            </Radio.Group>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(FixTypes)