import React, { FC } from "react";
import { Card, Row, Col, Divider } from "antd";
import { GetStatisticsData } from "../../services/statistics";
import { Column } from "@antv/g2plot";
import "./index.scss";

const HomePage: FC = (any) => {
  const [totalData, setTotalData]: any = React.useState({});
  const [totalItems, setTotalItems] = React.useState({
    user_count: {
      title: "住户人数",
      count: 0,
      describe: "小区当前已入住住户人数",
      color: "#db5050"
    },
    house_count: {
      title: "房屋数量",
      count: 0,
      describe: "小区当前房屋总数",
      color: "rgb(219 157 80)"
    },
    space_count: {
      title: "车位数量",
      count: 0,
      describe: "小区车位总数",
      color: "rgb(104 197 158)"
    },
    vehicle_count: {
      title: "车辆数量",
      count: 0,
      describe: "小区已登记车辆总数",
      color: "rgb(83 152 211)"
    }
  });

  React.useEffect(() => {
    GetStatisticsData().then((data) => {
      setTotalData(data);
	  var elements =  new Array();
      data.data.forEach((item) => {
		var element = {name: "待办",type: item.type,count: item.wait_count}
        elements.push(element);
		element = {name: "已办",type: item.type,count: item.finish_count}
        elements.push(element);
      });
	  initChart(elements);
    });
  }, []);

  const initChart = (elements) => {
    const stackedColumnPlot = new Column("line-chart", {
      data: elements,
      isGroup: true,
      xField: "type",
      yField: "count",
      seriesField: "name",
      /** 设置颜色 */
      color: ["#f88c24", "#1ca9e6"],
      /** 设置间距 */
      // marginRatio: 0.1,
      label: {
        // 可手动配置 label 数据标签位置
        position: "middle", // 'top', 'middle', 'bottom'
        // 可配置附加的布局方法
        layout: [
          // 柱形图数据标签位置自动调整
          { type: "interval-adjust-position" },
          // 数据标签防遮挡
          { type: "interval-hide-overlap" },
          // 数据标签文颜色自动调整
          { type: "adjust-color" }
        ]
      },
      meta: {
        type: {
          alias: "类型"
        },
        count: {
          alias: "数量"
        }
      }
    });

    stackedColumnPlot.render();
  };

  return (
    <Card title="">
      <Row justify="space-between" className="pl-10 pr-10">
        {Object.keys(totalItems).map((key) => (
          <Col span={5}>
            <div
              className="total-block"
              style={{ backgroundColor: totalItems[key]?.color }}
            >
              <div className="total-title">{totalItems[key]?.title}</div>
              <div className="total-count">
                {totalData[key] || totalItems[key].count}
              </div>
              {totalItems[key]?.describe}
            </div>
          </Col>
        ))}
      </Row>

      <Card
        bordered={false}
        headStyle={{ fontWeight: "bold" }}
        style={{ marginTop: 20 }}
        title="待办已办"
      >
        <div style={{ height: 440 }} id="line-chart" />
      </Card>
    </Card>
  );
};

export default HomePage;
