import React, {PropsWithChildren} from 'react'
import {
  Form, Card, Row, Col, Select, Radio, Input, Checkbox, Upload, Button, InputNumber, DatePicker, message
} from "antd"
import { PlusOutlined } from '@ant-design/icons'
import { useBuildingHouse } from "../building/hooks"
import { RentHouse } from "../../services/rent"
import { useHistory } from "react-router"
import './index.scss'

const defaultConfig = {
  1: '床',
  2: '天然气',
  3: '暖气',
  4: '宽带',
  5: '冰箱',
  6: '衣柜',
  7: '沙发',
  8: '空调',
  9: '电视',
  10: '热水器',
  11: '洗衣机',
}
const especiallyConfig = {
  1: '智能门锁',
  2: 'WIFI',
  3: '近地铁',
  4: '停车场',
  5: '独立卫生间',
  6: '私人阳台',
  7: '首次出租',
}

const LeaseCreate: React.FC = (props:PropsWithChildren<any>) => {

  const [currentHouse, setCurrentHouse]: any = React.useState({})
  const [buildHouse, setBuildHouse]: any = useBuildingHouse()

  React.useEffect(() => {
    setBuildHouse()
  }, [])

  const [housePic, setHousePic]: any = React.useState([])
  const [certPic, setCertPic]: any = React.useState([])

  const uploadButton = (
    <div>
      <PlusOutlined />
      <div style={{ marginTop: 8 }}>上传图片</div>
    </div>
  )

  const [form] = Form.useForm()
  const history = useHistory()

  const onSubmit = () => {
    const { wc_count, id: house_id } = currentHouse
    if (!house_id) return message.error('请先选择房屋！')
    if (!wc_count) return message.error('请输入卫生间数量！')
    if (!housePic.length) return message.error('请先上传房屋照片！')
    if (!certPic.length) return message.error('请先上传房屋证件照片！')
    form.validateFields().then(async values => {
      try {
        await RentHouse({
          method: 'post',
          ...values, wc_count,
          house_id,
          in_time: values.in_time.valueOf(),
          cert_pic: certPic.map(({ response }) => response.data),
          house_pic	: housePic.map(({ response }) => response.data),
          base_conf: (() => {
            let value = 0
            values?.base_conf.forEach(n => {
              value = value | (1 << n)
            })
            return value
          })(),
          special_conf: (() => {
            let value = 0
            values?.special_conf.forEach(n => {
              value = value | (1 << n)
            })
            return value
          })()
        })
        message.success('发布成功！')
        history.push('/admin/house/manager')
      } catch (e) {
        console.log(e)
      }
    })
  }

  return (
    <Card>
      <Form labelCol={{ span: 7 }} wrapperCol={{ span: 17 }} form={form}>
        <Row>
          <div className={'form-block__title'}>房屋基本信息</div>
          <Col span={8}>
            <Form.Item label='房屋'>
              <Select placeholder="请选择" onChange={(valueIndex: any) => {
                setCurrentHouse(buildHouse[valueIndex])
              }}>
                {
                  buildHouse.map((house, index) =>
                    <Select.Option value={index}>{ house.label }</Select.Option>
                  )
                }
              </Select>
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='楼层'>{ currentHouse.layer || '未选择房屋' }</Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='建筑面积'>{ currentHouse.house_area || '未选择房屋' }</Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='朝向' name="direction" rules={[{ required: true }]}>
              <Select placeholder="请选择" options={[
                { label: '东', value: 1 },
                { label: '南', value: 2 },
                { label: '西', value: 3 },
                { label: '北', value: 4 },
              ]} />
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='户型'>
              <Input
                addonBefore={'室'}
                disabled
                value={currentHouse.room_count}
                style={{ width: '100px', marginRight: 10 }}
                placeholder='一室'
              />
              <Input
                addonBefore={'厅'}
                disabled
                value={currentHouse.hall_count}
                style={{ width: '100px', marginRight: 10 }}
                placeholder={'一厅'}
              />
              <InputNumber
                style={{ width: '100px' }}
                placeholder="卫"
                onChange={(value) => {
                  setCurrentHouse({ ...currentHouse, wc_count: value })
                }}
              />
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='装修情况' name='decorating' rules={[{ required: true }]} >
              <Select placeholder={'精装修'} options={[
                { label: '精装', value: 1 },
                { label: '简装', value: 2 },
                { label: '清水', value: 3 },
              ]}/>
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label='是否有电梯'>
              <Radio.Group value={currentHouse.has_lift} disabled >
                <Radio value={true}>是</Radio>
                <Radio value={false}>否</Radio>
              </Radio.Group>
            </Form.Item>
          </Col>
        </Row>
        {/* 联系人信息 */}
        <Row>
          <div className={'form-block__title'}>联系人信息</div>
          <Col span={6}>
            <Form.Item label={'联系人'} name="contacter" rules={[{ required: true }]}>
              <Input placeholder="单行输入" />
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label={'联系方式'} name="contact_phone" rules={[{ required: true }]}>
              <Input placeholder="单行输入" />
            </Form.Item>
          </Col>
        </Row>
        <Row>
          <div className={'form-block__title'}>租房信息</div>
          <Col span={6}>
            <Form.Item className='w-4/5' label='付款方式' name="pay_time_type" rules={[{ required: true }]}>
              <Select placeholder={'请选择'} options={[
                { label: '月付', value: 1 },
                { label: '季付', value: 2 },
                { label: '半年付', value: 3 },
                { label: '年付', value: 4 }
              ]} />
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='出租方式' name="rent_type" rules={[{ required: true }]}>
              <Select placeholder={'请选择'} options={[
                { label: '整租', value: 1 },
                { label: '合租', value: 2 },
                { label: '转租', value: 3 }
              ]} />
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='房间类型' name="room_type" rules={[{ required: true }]}>
              <Select placeholder={'请选择'} options={[
                { label: '全部', value: 1 },
                { label: '主卧', value: 2 },
                { label: '次卧', value: 3 }
              ]} />
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='面积' name="room_area" rules={[{ required: true }]} >
              <InputNumber placeholder={'请选择'}/>
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='租金(元/月)' name="rent_price" rules={[{ required: true }]}>
              <InputNumber placeholder={'请输入'}/>
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='押金(元)' name="desposit" rules={[{ required: true }]}>
              <InputNumber placeholder={'请输入'}/>
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='服务费(元)' name="service_price" rules={[{ required: true }]}>
              <InputNumber placeholder={'请输入'}/>
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='中介费(元)' name="intermediary_price" rules={[{ required: true }]}>
              <InputNumber placeholder={'请输入'}/>
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item className={'w-4/5'} label='可入住时间' name="in_time" rules={[{ required: true }]}>
              <DatePicker placeholder={'请输入'}/>
            </Form.Item>
          </Col>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>基本配置</div>
          <Form.Item
            label="内容"
            style={{ width: "100%" }}
            wrapperCol={{ span: 22 }}
            labelCol={{ span: 2 }}
            name="base_conf"
            rules={[{ required: true }]}
          >
            <Checkbox.Group>
              {
                Object.keys(defaultConfig).map((key, index) => (
                  <Checkbox value={index} key={key}>{defaultConfig[key]}</Checkbox>
                ))
              }
            </Checkbox.Group>
          </Form.Item>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>特色</div>
          <Form.Item
            label="内容"
            name="special_conf"
            style={{ width: "100%" }}
            wrapperCol={{ span: 22 }}
            labelCol={{ span: 2 }}
            rules={[{ required: true }]}
          >
            <Checkbox.Group>
              {
                Object.keys(especiallyConfig).map((key, index) => (
                  <Checkbox value={index} key={key}>{especiallyConfig[key]}</Checkbox>
                ))
              }
            </Checkbox.Group>
          </Form.Item>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>房屋照片</div>
          <div style={{ textAlign: 'left' }}>
            <Upload
              action="http://localhost:3000/api/v1/upload"
              listType="picture-card"
              fileList={housePic}
              onChange={(({ fileList }) => setHousePic(fileList))}
            >
              { uploadButton }
            </Upload>
          </div>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>房屋证件</div>
          <div style={{ textAlign: 'left' }}>
            <Upload
              action="http://localhost:3000/api/v1/upload"
              listType="picture-card"
              fileList={certPic}
              onChange={(({ fileList }) => setCertPic(fileList))}
            >
              { uploadButton }
            </Upload>
          </div>
        </Row>
        <Row className={'mb-5'}>
          <div className={'form-block__title'}>房屋简介</div>
          <Form.Item className="w-4/5" name="desc" rules={[{ required: true }]}>
            <Input.TextArea placeholder="多行输入" rows={4} />
          </Form.Item>
        </Row>
        <Form.Item>
          <Button type="primary" onClick={onSubmit}>发布房源</Button>
        </Form.Item>
      </Form>
    </Card>
  )
}

export default LeaseCreate
