import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal } from 'antd'
import { withRouter } from 'react-router-dom'
import { RentHouse, RentHouseManager } from '../../services/rent'
import './index.scss'

const Activity: React.FC = (props: any) => {

  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '房屋',
      dataIndex: 'house_name',
      search: false,
    },
    {
      title: '联系人',
      dataIndex: 'contacter'
    },
    {
      title: '联系人电话',
      dataIndex: 'contact_phone',
    },
    {
      title: '期望租金',
      dataIndex: 'rent_price',
      search: false,
    },
    {
      title: '出租方式',
      dataIndex: 'rent_type',
      valueEnum: {
        1: { text: '整租' },
        2: { text: '合租' },
        3: { text: '转租' },
      }
    },
    {
      title: '建筑面积',
      dataIndex: 'room_area',
      search: false,
    },
    {
      title: '装修情况',
      dataIndex: 'decorating',
      search: false,
      valueEnum: {
        1: { text: '精装' },
        2: { text: '简装' },
        3: { text: '清水' },
      }
    },
    {
      title: '状态',
      dataIndex: 'approve_status',
      valueType: 'select',
      valueEnum: {
        1: { text: '待审核', status: 'Default' },
        2: { text: '通过', status: 'Success',},
        3: { text: '未通过', status: 'Error' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: 210,
	  align: 'center',
      render: (_, row, index, action) => [
        <a style={{marginRight: 20 }} onClick={() => {}}>审核</a>,
        <a style={{marginRight: 20 }} onClick={() => {}}>分配经纪人</a>,
        <a style={{marginRight: 20 }} onClick={() => {}}>详情</a>,
        <a onClick={() => {}}>下架</a>
      ]
    }
  ]
  const [state, setState] = useState({ visible: true })

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={{
          optionRender: false,
          collapsed: false,
        }}
        request={RentHouse}
        toolBarRender={() => [
          <Button
            type="primary"
            onClick={() => {
              props.history.push('/admin/house/lease-create')
            }}
          >经纪人管理</Button>,
          <Button
            type="primary"
            onClick={() => {
              props.history.push('/admin/house/lease-create')
            }}
          >发布房源</Button>
        ]}
        columns={columns}
      />
      <Modal
        title="经纪人管理"
        visible={state.visible}
        width={1200}
        onCancel={() => setState(prevState => ({ ...prevState, visible: false }))}
      >
        <ProTable
          search={false}
        />
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(Activity)