import React, { FC } from 'react'
import './index.scss'
import { GetProvinceCityArea } from '../../services/api'
import { Form, Card, Divider, Select, Input, Button } from 'antd'

const GardenCreate: FC = () => {
  const [areaData, setAreaData] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })
  // cache
  const [areaDataCache, setAreaDataCache] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })

  React.useEffect(() => {
    GetProvinceCityArea({}).then(res => {
      setAreaDataCache(res.data)
      setAreaData(pre => ({
        ...pre,
        province_list: res.data.province_list
      }))
    })
  }, [])

  return (
    <Card>
      <div className='custom-card-title'>小区管理/新增小区</div>
      <Divider/>
      <Form
        labelCol={{ span: 2 }}
        wrapperCol={{ span: 12 }}
        initialValues={{ remember: true }}
        labelAlign={'right'}
      >
        <div className='custom-form-title'>基本信息</div>
        <Form.Item label='城市' required className='selector-line'>
          <Select
            placeholder='省份'
            style={{ width: 200 }}
            onChange={
              (value) => {
                setAreaData(pre => ({
                  ...pre,
                  city_list: areaDataCache.city_list.filter((item: any) => item.province_code === value)
                }))
              }
            }>
            {
              areaData.province_list.map((province: any) => {
                return <Select.Option value={province.code} key={province.code}>{province.name}</Select.Option>
              })
            }
          </Select>
          <Select
            placeholder='城市'
            style={{ width: 200 }}
            onChange={
              (value) => {
                setAreaData(pre => ({
                  ...pre,
                  area_list: areaDataCache.area_list.filter((item: any) => item.city_code === value)
                }))
              }
            }
          >
            {
              areaData.city_list.map((item: any) => {
                return <Select.Option value={item.code} key={item.code}>{item.name}</Select.Option>
              })
            }
          </Select>
          <Select placeholder='区域' style={{ width: 200 }}>
            {
              areaData.area_list.map((item: any) => {
                return <Select.Option value={item.code} key={item.code}>{item.name}</Select.Option>
              })
            }
          </Select>
        </Form.Item>
        <Form.Item label='街道' className='selector-line'>
          <Select placeholder='街道'>
            <Select.Option value={1}>街道1</Select.Option>
          </Select>
          <Select placeholder='社区'>
            <Select.Option value={1}>街道1</Select.Option>
          </Select>
        </Form.Item>
        <Form.Item label='小区名称' required>
          <Input placeholder='单行输入' />
        </Form.Item>
        <Form.Item label='地址' required>
          <Input placeholder='单行输入' />
        </Form.Item>
        <Form.Item label='物业联系人'>
          <Input placeholder='单行输入' />
        </Form.Item>
        <Form.Item label='物业电话'>
          <Input placeholder='单行输入' />
        </Form.Item>
        <Form.Item>
          <Button type='primary'>创建</Button>
        </Form.Item>
      </Form>
    </Card>
  )
}

export default GardenCreate