import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import {Button, Modal, Form, Select, Input, InputNumber, message} from 'antd'
import { withRouter } from 'react-router-dom'
import { Car } from '../../services/parking'
import { useHousehold } from "../Owner/hooks"
import { useParkingPosition } from './hooks'
import { SELECTOR_CAR_TYPE, SELECTOR_CAR_BIND_TYPE } from '../../CONSTANT'
import './index.scss'

const ParkingCar: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '车牌号',
      dataIndex: 'plate_no',
      search: true,
    },
    {
      title: '车牌类型',
      dataIndex: 'bind_type',
      search: true,
      valueType: 'select',
      hideInTable: true
    },
    {
      title: '车架号',
      dataIndex: 'vin',
      search: false,
    },
    {
      title: '车辆品牌',
      dataIndex: 'brand',
      search: false,
    },
    {
      title: '车辆类型',
      dataIndex: 'vehicle_type',
      valueType: 'select',
      search: true,
    },
    {
      title: '车身颜色',
      dataIndex: 'color',
      search: false,
    },
    {
      title: '车位',
      dataIndex: 'space_number',
      search: false,
    },
    {
      title: '车位绑定类型',
      dataIndex: 'vehicle_type',
      valueEnum: {
        1: { text: '出租' },
        2: { text: '出售' }
      },
      search: false,
    },
    {
      title: '车辆品牌',
      dataIndex: 'brand',
      search: false,
    },
    {
      title: '住户',
      dataIndex: 'household_name',
      search: false,
      render: (_, row) => <div>{row.household_name}-{row.household_phone}</div>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        const queryParams = `?obj_type=3&obj_id=${row.id}&name=${row.plate_no}`
        return [
          <a style={{marginRight: 20 }} onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
          }}>编辑</a>,
          <a style={{marginRight: 20 }} onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await Car({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>,
          <a onClick={() => {
            props.history.push('/admin/car/bill' + queryParams)
          }}>费用</a>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const [household, setHousehold] = useHousehold()
  const [parkingPosition, setParkingPosition] = useParkingPosition()

  React.useEffect(() => {
    setHousehold()
    setParkingPosition()
  }, [])

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await Car({ method: 'post', ...values })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={Car}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='添加住户车辆'
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='车牌号' name="plate_no" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车辆类型' name="vehicle_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={SELECTOR_CAR_TYPE} />
          </Form.Item>
          <Form.Item label='车架号' name="vin" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='发动机号' name="engine_no" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车辆品牌' name="brand" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车身颜色' name="color" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='排量' name="displacement" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label="排量单位" name="displacement_unit" rules={[{ required: true }]}>
            <Select placeholder="请选择">
              <Select.Option value="l">L</Select.Option>
              <Select.Option value="t">T</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item label='座位数' name="seat" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='住户' name="household_uid" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={household} />
          </Form.Item>
          <Form.Item label='车位' name="space_id">
            <Select placeholder="请选择" options={parkingPosition} />
          </Form.Item>
          <Form.Item label='车位绑定类型' name="bind_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={SELECTOR_CAR_BIND_TYPE} />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ParkingCar)
