import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { Parking } from '../../services/parking'
import './index.scss'

const ChargeHouse: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '区域编号',
      dataIndex: 'park_number',
      search: true,
    },
    {
      title: '区域名称',
      dataIndex: 'park_name',
      search: false,
    },
    {
      title: '类型',
      dataIndex: 'park_type',
      search: false,
      valueEnum: {
        1: { text: '地上停车场' },
        2: { text: '地下停车场' }
      }
    },
    {
      title: '车位数',
      dataIndex: 'space_count',
      search: false,
    },
    {
      title: '备注',
      dataIndex: 'comment',
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a style={{marginRight: 20 }} onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
          }}>编辑</a>,
          <a onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await Parking({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>,
          // <Button onClick={() => {
          //   props.history.push('/admin/car/bill' + queryParams)
          // }}>添加车位</Button>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await Parking({
        ...values,
        method: state.editId ? 'put' : 'post',
        id: state.editId
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={Parking}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ visible: true, editId: null }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId? "编辑停车场": "添加停车场"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='区域编号' name="park_number" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='区域名称' name="park_name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='类型' name="park_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '地上停车场', value: 1 },
              { label: '地下停车场', value: 2 },
            ]} />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ChargeHouse)