import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Input, message, InputNumber } from 'antd'
import { withRouter } from 'react-router-dom'
import { ParkingPosition } from '../../services/parking'
import { useBuildingHouse } from "../building/hooks"
import { useParking } from "./hooks"
import './index.scss'

const ParkingPositionPage: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '区域名称',
      dataIndex: 'park_number',
      search: false,
    },
    {
      title: '停车场',
      dataIndex: 'park_name',
      hideInTable: true,
      valueType: 'select',
      search: true,
      renderFormItem: (_, { type, defaultRender, formItemProps, fieldProps, ...rest }, form) => {
        if (type === 'form') {
          return null;
        }
        const status = form.getFieldValue('state');
        if (status !== 'open') {
          return (
            // value 和 onchange 会通过 form 自动注入。
            <Select placeholder="请选择" options={parking} />
          );
        }
        return defaultRender(_);
      }
    },
    {
      title: '车位编号',
      dataIndex: 'space_number',
      search: true,
    },
    {
      title: '车位类型',
      dataIndex: 'space_type',
      search: true,
      valueEnum: {
        1: { text: '普通车位' },
        2: { text: '子母车位' },
        3: { text: '豪华车位' },
      }
    },
    {
      title: '面积',
      dataIndex: 'space_area',
      search: false,
    },
    {
      title: '车位状态',
      dataIndex: 'space_status',
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a style={{marginRight: 20 }} onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
          }}>编辑</a>,
          <a style={{marginRight: 20 }} onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await ParkingPosition({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>,
          <a onClick={() => {
          }}>绑定车辆</a>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const [buildingHouse, setBuildingHouse] = useBuildingHouse()
  const [parking, setParking] = useParking()
  React.useEffect(() => {
    // init
    setBuildingHouse()
    setParking()
  }, [])

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await ParkingPosition({
        ...values,
        method: state.editId ? 'put' : 'post',
        id: state.editId
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={ParkingPosition}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ visible: true, editId: null }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId? "编辑停车位": "添加停车位"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='区域' name="park_id" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={parking} />
          </Form.Item>
          <Form.Item label='车位编码' name="space_number" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='车位类型' name="space_type" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={[
              { label: '普通车位', value: 1 },
              { label: '子母车位', value: 2 },
              { label: '豪华车位', value: 3 }
            ]} />
          </Form.Item>
          <Form.Item label='面积' name="space_area" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='绑定房屋' name="house_id" rules={[{ required: true }]}>
            <Select placeholder='请选择' options={buildingHouse} />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(ParkingPositionPage)