import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import {Button, Modal, Form, Select, Input, message} from 'antd'
import { withRouter } from 'react-router-dom'
import { User } from '../../services/user'
import './index.scss'

const Roles: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '用户名',
      dataIndex: 'user_name',
      search: true,
    },
    {
      title: '电话号码',
      dataIndex: 'phone',
      search: false,
    },
    {
      title: '邮箱',
      dataIndex: 'email',
      search: false,
    },
    {
      title: '权限组',
      dataIndex: 'group_name',
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width: 210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a style={{marginRight: 20 }} onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({
              ...prevState,
              visible: true,
              editId: row.id
            }))
          }}>编辑</a>,
          <a onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await User({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })

  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await User({
        method: 'post',
        ...values,
        group_id: 11,
        department_id: 0
      })
      message.success('操作成功！')
      form.resetFields()
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        search={false}
        request={User}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState(preState => ({ ...preState, visible: true }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title='添加用户'
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='权限组' name="group_id" rules={[{ required: false }]}>
            <Select placeholder='请选择' options={[]} />
          </Form.Item>
          <Form.Item label='部门' name="department_id">
            <Select placeholder='请选择' options={[]} />
          </Form.Item>
          <Form.Item label='用户名' name="user_name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='密码' name="password" rules={[{ required: true }]}>
            <Input type="password" placeholder="请输入" />
          </Form.Item>
          <Form.Item label='真实名称' name="real_name " rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='联系方式' name="phone" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='邮箱' name="email" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(Roles)