import React from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import {
  Button,
  Modal,
  Form,
  Select,
  Input,
  message,
  InputNumber,
  Space
} from "antd";
import { withRouter } from "react-router-dom";
import { BuildingHouse, BuildingUnit } from "../../services/building";
import { SELECTOR_HOUSE_TYPE } from "../../CONSTANT";
import { useBuilding } from "./hooks";
import "./index.scss";

const ParkingPositionPage: React.FC = (props: any) => {
  const columns: any = [
    {
      title: "房屋",
      dataIndex: "house_name",
      search: true
    },
    {
      title: "房号",
      dataIndex: "house_number",
      search: true
    },
    {
      title: "楼层",
      dataIndex: "layer",
      search: true
    },
    {
      title: "类型",
      dataIndex: "house_type",
      valueType: "select",
      valueEnum: {
        1: { text: "住宅" },
        2: { text: "公寓" },
        3: { text: "商业" },
        4: { text: "洋房" },
        5: { text: "别墅" }
      },
      search: true
    },
    {
      title: "建筑面积(㎡)",
      dataIndex: "house_area",
      search: false
    },
    {
      title: "使用面积(㎡)",
      dataIndex: "house_used_area",
      search: false
    },
    {
      title: "房屋状态",
      dataIndex: "status",
      search: true,
      valueEnum: {
        1: { text: "未入住" },
        2: { text: "已入住" },
        3: { text: "已出租" }
      }
    },
    {
      title: "备注",
      dataIndex: "comment",
      search: false
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      width: 210,
      align: "center",
      render: (_, row, index, action) => {
        return [
          <a
            style={{ marginRight: 20 }}
            onClick={() => {
              form.setFieldsValue(row);
              setState((prevState) => ({
                ...prevState,
                visible: true,
                editId: row.id
              }));
            }}
          >
            编辑
          </a>,
          <a
            style={{ marginRight: 20 }}
            onClick={() => {
              Modal.confirm({
                title: "删除记录",
                content: "你确定删除这条记录吗？",
                onOk: async () => {
                  await BuildingHouse({ method: "delete", id: row.id });
                  message.success("操作成功！");
                  actionRef.current.reload();
                }
              });
            }}
          >
            删除
          </a>,
          <a onClick={() => {}}>人员</a>
        ];
      }
    }
  ];
  const [buildings, setBuildings] = useBuilding();
  const [units, setUnits] = React.useState([]);
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  });

  const onChangeBuilding = (value) => {
    const params = { page_size: -1, building_id: value };
    BuildingUnit(params).then(({ data }) => {
      setUnits(
        data?.map(({ unit_name, id }) => ({ value: id, label: unit_name }))
      );
    });
  };
  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      await BuildingHouse({
        ...values,
        method: state.editId ? "put" : "post",
        id: state.editId
      });
      message.success("操作成功！");
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false }));
    });
  };
  React.useEffect(() => {
    setBuildings();
  }, []);

  const limitNumber = (value) => {
    if (typeof value === "string") {
      return !isNaN(Number(value)) ? value.replace(/^(0+)|[^\d]/g, "") : "";
    } else if (typeof value === "number") {
      return !isNaN(value) ? String(value).replace(/^(0+)|[^\d]/g, "") : "";
    } else {
      return "";
    }
  };

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={BuildingHouse}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields();
              setState((preState) => ({ visible: true, editId: null }));
            }}
          >
            添加
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? "编辑房屋" : "添加房屋"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item
            label="楼栋"
            name="building_id"
            rules={[{ required: true }]}
          >
            <Select
              placeholder="请选择楼栋"
              options={buildings}
              onChange={onChangeBuilding}
              allowClear
            />
          </Form.Item>
          <Form.Item label="单元" name="unit_id" rules={[{ required: true }]}>
            <Select placeholder="请选择单元" options={units} allowClear />
          </Form.Item>
          <Form.Item
            label="房间号"
            name="house_number"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入房间号" />
          </Form.Item>
          <Form.Item label="楼层" name="layer" rules={[{ required: true }]}>
            <InputNumber
              placeholder="请输入楼层"
              formatter={limitNumber}
              min={0}
            />
          </Form.Item>

          <Form.Item label="房屋户型">
            <Space>
              <Form.Item
                noStyle
                name="room_count"
                rules={[{ required: false }]}
                style={{ display: "inline-block" }}
              >
                <InputNumber formatter={limitNumber} min={0} max={10} />
              </Form.Item>
              室
              <Form.Item
                noStyle
                name="hall_count"
                rules={[{ required: false }]}
                style={{
                  display: "inline-block",
                  width: "calc(50% - 8px)",
                  margin: "0 8px"
                }}
              >
                <InputNumber formatter={limitNumber} min={0} max={10} />
              </Form.Item>
              厅
            </Space>
          </Form.Item>
          <Form.Item
            label="房屋类型"
            name="house_type"
            rules={[{ required: true }]}
          >
            <Select
              placeholder="请选择房屋类型"
              options={SELECTOR_HOUSE_TYPE}
            />
          </Form.Item>
          <Form.Item
            label="建筑面积（㎡）"
            name="house_area"
            rules={[{ required: true }]}
          >
            <InputNumber
              placeholder="请输入建筑面积"
              min={0}
              style={{width: 160}}
            />
          </Form.Item>
          <Form.Item
            label="使用面积（㎡）"
            name="house_used_area"
            rules={[{ required: true }]}
          >
            <InputNumber
              placeholder="请输入使用面积"
              min={0}
              style={{width: 160}}
            />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(ParkingPositionPage);
