import React from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { Button, Modal, Form, Input, InputNumber, message } from "antd";
import { withRouter } from "react-router-dom";
import { Building } from "../../services/building";
import {PlusOutlined} from "@ant-design/icons";
import "./index.scss";

const BuildingList: React.FC = (props: any) => {
  const columns: any = [
    {
      title: "楼栋名",
      dataIndex: "building_name",
      search: false
    },
    {
      title: "楼栋编号",
      dataIndex: "building_number",
      search: true
    },
    {
      title: "单元数",
      dataIndex: "unit_count",
      search: false
    },
    {
      title: "建筑面积",
      dataIndex: "building_area",
      search: false
    },
    {
      title: "备注",
      dataIndex: "comment",
      search: false
    },
    {
      title: "操作",
      dataIndex: "option",
      search: false,
      width: 300,
      align: "center",
      render: (_, row, index, action) => {
        return [
          <a
            style={{ marginRight: 20 }}
            onClick={() => {
              form.setFieldsValue(row);
              setState((prevState) => ({
                ...prevState,
                visible: true,
                editId: row.id
              }));
            }}
          >
            编辑
          </a>,
          <a
            style={{ marginRight: 20 }}
            onClick={() => {
              Modal.confirm({
                title: "删除记录",
                content: "你确定删除这条记录吗？",
                onOk: async () => {
                  await Building({ method: "delete", id: row.id });
                  message.success("操作成功！");
                  actionRef.current.reload();
                }
              });
            }}
          >
            删除
          </a>,
          <a
            style={{ marginRight: 20 }}
            onClick={() => {
              props.history.push("/admin/building/unit");
            }}
          >
            添加单元
          </a>,
          <a
            onClick={() => {
              props.history.push("/admin/building/unit");
            }}
          >
            管家
          </a>
        ];
      }
    }
  ];
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  });
  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm();
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      await Building({
        ...values,
        method: state.editId ? "put" : "post",
        id: state.editId
      });
      message.success("操作成功！");
      actionRef.current?.reloadAndRest();
      setState((prevState) => ({ ...prevState, visible: false }));
    });
  };

  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={Building}
        toolBarRender={() => [
          <Button
		    icon={<PlusOutlined />}
            style={{ borderRadius: "5px" }}
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields();
              setState((preState) => ({ visible: true, editId: null }));
            }}
          >
            添加楼栋
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId ? "编辑楼栋" : "添加楼栋"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState((pre) => ({ ...pre, visible: false }))}
      >
        <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
          <Form.Item
            label="楼栋编号"
            name="building_number"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="楼栋名"
            name="building_name"
            rules={[{ required: true }]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="建筑面积"
            name="building_area"
            rules={[{ required: false }]}
          >
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label="备注" name="comment">
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default withRouter(BuildingList);
