import React, { useEffect } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, message, Select, Radio } from 'antd'
import { withRouter } from 'react-router-dom'
import { BuildingUnit } from '../../services/building'
import { useBuilding } from './hooks'
import './index.scss'

const BuildingsUnit: React.FC = (props: any) => {
  const columns: any = [
    {
      title: '楼栋名',
      dataIndex: 'building_name',
      search: false,
    },
    {
      title: '单元编号',
      dataIndex: 'unit_number',
      search: true,
    },
    {
      title: '楼栋',
      dataIndex: 'building_id',
      hideInTable: true,
      valueType: 'select',
      search: true,
      renderFormItem: (_, { type, defaultRender, formItemProps, fieldProps, ...rest }, form) => {
        if (type === 'form') {
          return null;
        }
        const status = form.getFieldValue('state');
        if (status !== 'open') {
          return (
            // value 和 onchange 会通过 form 自动注入。
            <Select placeholder="请选择" options={buildings} />
          );
        }
        return defaultRender(_);
      }

    },
    {
      title: '单元名',
      dataIndex: 'unit_name',
      search: false,
    },
    {
      title: '总层数',
      dataIndex: 'unit_layers',
      search: false,
    },
    {
      title: '是否有电梯',
      dataIndex: 'has_lift',
      search: false,
      render: (_, record: any) => <span>{ record.has_lift ? '是' : '否' }</span>
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
	  width:210,
	  align: 'center',
      render: (_, row, index, action) => {
        return [
          <a style={{marginRight: 20 }} onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
          }}>编辑</a>,
          <a style={{marginRight: 20 }} onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await BuildingUnit({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</a>,
          <a onClick={() => {
            props.history.push('/admin/building/house')
          }}>添加房屋</a>
        ]
      }
    }
  ]
  const [buildings, setBuildings] = useBuilding()
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await BuildingUnit({
        ...values,
		id: state.editId,
        method: state.editId ? 'put' : 'post'
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  useEffect(() => {
    setBuildings()
  }, []);


  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="key"
        request={BuildingUnit}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ visible: true, editId: null }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId? "编辑单元": "添加单元"}
        visible={state.visible}
        width={600}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='楼栋' name="building_id" rules={[{ required: true }]}>
            <Select placeholder="请选择" options={buildings} />
          </Form.Item>
          <Form.Item label='单元编号' name="unit_number" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='单元名' name="unit_name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='总层数' name="unit_layers" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='是否有电梯' name="has_lift" rules={[{ required: true }]}>
            <Radio.Group>
              <Radio value={true}>是</Radio>
              <Radio value={false}>否</Radio>
            </Radio.Group>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(BuildingsUnit)